import builtins
from typing import Any, Final, TypeAlias

decoded_info: TypeAlias = Any
points: TypeAlias = Any
decoded_type: TypeAlias = Any
retval: TypeAlias = Any

class BarcodeDetector:
    def decode(self, img, points) -> tuple[retval, decoded_info, decoded_type]:
        """
        @brief Decodes barcode in image once it's found by the detect() method.
        *
        * @param img grayscale or color (BGR) image containing bar code.
        * @param points vector of rotated rectangle vertices found by detect() method (or some other algorithm). * For N detected barcodes, the dimensions of this array should be [N][4]. * Order of four points in vector<Point2f> is bottomLeft, topLeft, topRight, bottomRight.
        * @param decoded_info UTF8-encoded output vector of string or empty vector of string if the codes cannot be decoded.
        * @param decoded_type vector of BarcodeType, specifies the type of these barcodes
        """

    def detect(self, img, points=...) -> tuple[retval, points]:
        """
        @brief Detects Barcode in image and returns the rectangle(s) containing the code.
        *
        * @param img grayscale or color (BGR) image containing (or not) Barcode.
        * @param points Output vector of vector of vertices of the minimum-area rotated rectangle containing the codes. * For N detected barcodes, the dimensions of this array should be [N][4]. * Order of four points in vector< Point2f> is bottomLeft, topLeft, topRight, bottomRight.
        """

    def detectAndDecode(self, img, points=...) -> tuple[retval, decoded_info, decoded_type, points]:
        """
        @brief Both detects and decodes barcode

        * @param img grayscale or color (BGR) image containing barcode.
        * @param decoded_info UTF8-encoded output vector of string(s) or empty vector of string if the codes cannot be decoded.
        * @param decoded_type vector of BarcodeType, specifies the type of these barcodes
        * @param points optional output vector of vertices of the found  barcode rectangle. Will be empty if not found.
        """

EAN_13: Final[int]
EAN_8: Final[int]
NONE: Final[int]
UPC_A: Final[int]
UPC_E: Final[int]
UPC_EAN_EXTENSION: Final[int]



from typing import Any, Final, overload, TypeAlias

rvecs: TypeAlias = Any
K2: TypeAlias = Any
D1: TypeAlias = Any
R1: TypeAlias = Any
map1: TypeAlias = Any
T: TypeAlias = Any
R2: TypeAlias = Any
distorted: TypeAlias = Any
D: TypeAlias = Any
P: TypeAlias = Any
K1: TypeAlias = Any
map2: TypeAlias = Any
R: TypeAlias = Any
Q: TypeAlias = Any
jacobian: TypeAlias = Any
P2: TypeAlias = Any
D2: TypeAlias = Any
K: TypeAlias = Any
imagePoints: TypeAlias = Any
P1: TypeAlias = Any
tvecs: TypeAlias = Any
undistorted: TypeAlias = Any

retval: TypeAlias = Any

@overload
def calibrate(objectPoints, imagePoints, image_size, K, D, rvecs=..., tvecs=..., flags=..., criteria=...) -> tuple[retval, K, D, rvecs, tvecs]:
    """
    @brief Performs camera calibration

        @param objectPoints vector of vectors of calibration pattern points in the calibration pattern
    """

@overload
def calibrate(objectPoints, imagePoints, image_size, K, D, rvecs=..., tvecs=..., flags=..., criteria=...) -> tuple[retval, K, D, rvecs, tvecs]:
    """
    @param imagePoints vector of vectors of the projections of calibration pattern points.
    """

@overload
def calibrate(objectPoints, imagePoints, image_size, K, D, rvecs=..., tvecs=..., flags=..., criteria=...) -> tuple[retval, K, D, rvecs, tvecs]:
    """ """

@overload
def calibrate(objectPoints, imagePoints, image_size, K, D, rvecs=..., tvecs=..., flags=..., criteria=...) -> tuple[retval, K, D, rvecs, tvecs]:
    """
    @param image_size Size of the image used only to initialize the camera intrinsic matrix.
    @param K Output 3x3 floating-point camera intrinsic matrix
    \f$\cameramatrix{A}\f$ . If
    @ref fisheye::CALIB_USE_INTRINSIC_GUESS is specified, some or all of fx, fy, cx, cy must be
    """

@overload
def calibrate(objectPoints, imagePoints, image_size, K, D, rvecs=..., tvecs=..., flags=..., criteria=...) -> tuple[retval, K, D, rvecs, tvecs]:
    """
    @param D Output vector of distortion coefficients \f$\distcoeffsfisheye\f$.
    @param rvecs Output vector of rotation vectors (see Rodrigues ) estimated for each pattern view.
    """

@overload
def calibrate(objectPoints, imagePoints, image_size, K, D, rvecs=..., tvecs=..., flags=..., criteria=...) -> tuple[retval, K, D, rvecs, tvecs]:
    """ """

@overload
def calibrate(objectPoints, imagePoints, image_size, K, D, rvecs=..., tvecs=..., flags=..., criteria=...) -> tuple[retval, K, D, rvecs, tvecs]:
    """ """

@overload
def calibrate(objectPoints, imagePoints, image_size, K, D, rvecs=..., tvecs=..., flags=..., criteria=...) -> tuple[retval, K, D, rvecs, tvecs]:
    """ """

@overload
def calibrate(objectPoints, imagePoints, image_size, K, D, rvecs=..., tvecs=..., flags=..., criteria=...) -> tuple[retval, K, D, rvecs, tvecs]:
    """
    @param tvecs Output vector of translation vectors estimated for each pattern view.
    @param flags Different flags that may be zero or a combination of the following values:
    -    @ref fisheye::CALIB_USE_INTRINSIC_GUESS  cameraMatrix contains valid initial values of
    """

@overload
def calibrate(objectPoints, imagePoints, image_size, K, D, rvecs=..., tvecs=..., flags=..., criteria=...) -> tuple[retval, K, D, rvecs, tvecs]:
    """ """

@overload
def calibrate(objectPoints, imagePoints, image_size, K, D, rvecs=..., tvecs=..., flags=..., criteria=...) -> tuple[retval, K, D, rvecs, tvecs]:
    """
    -    @ref fisheye::CALIB_RECOMPUTE_EXTRINSIC  Extrinsic will be recomputed after each iteration
    """

@overload
def calibrate(objectPoints, imagePoints, image_size, K, D, rvecs=..., tvecs=..., flags=..., criteria=...) -> tuple[retval, K, D, rvecs, tvecs]:
    """
    -    @ref fisheye::CALIB_CHECK_COND  The functions will check validity of condition number.
    -    @ref fisheye::CALIB_FIX_SKEW  Skew coefficient (alpha) is set to zero and stay zero.
    -    @ref fisheye::CALIB_FIX_K1,..., @ref fisheye::CALIB_FIX_K4 Selected distortion coefficients
    """

@overload
def calibrate(objectPoints, imagePoints, image_size, K, D, rvecs=..., tvecs=..., flags=..., criteria=...) -> tuple[retval, K, D, rvecs, tvecs]:
    """
        -    @ref fisheye::CALIB_FIX_PRINCIPAL_POINT  The principal point is not changed during the global
    optimization. It stays at the center or at a different location specified when @ref fisheye::CALIB_USE_INTRINSIC_GUESS is set too.
        -    @ref fisheye::CALIB_FIX_FOCAL_LENGTH The focal length is not changed during the global
    optimization. It is the \f$max(width,height)/\pi\f$ or the provided \f$f_x\f$, \f$f_y\f$ when @ref fisheye::CALIB_USE_INTRINSIC_GUESS is set too.
        @param criteria Termination criteria for the iterative optimization algorithm.
    """

@overload
def distortPoints(undistorted, K, D, distorted=..., alpha=...) -> distorted:
    """
    @brief Distorts 2D points using fisheye model.

        @param undistorted Array of object points, 1xN/Nx1 2-channel (or vector\<Point2f\> ), where N is
    """

@overload
def distortPoints(undistorted, K, D, distorted=..., alpha=...) -> distorted:
    """
    @param K Camera intrinsic matrix \f$cameramatrix{K}\f$.
    @param D Input vector of distortion coefficients \f$\distcoeffsfisheye\f$.
    @param alpha The skew coefficient.
    @param distorted Output array of image points, 1xN/Nx1 2-channel, or vector\<Point2f\> .
    """

@overload
def distortPoints(undistorted, K, D, distorted=..., alpha=...) -> distorted:
    """ """

@overload
def distortPoints(undistorted, K, D, distorted=..., alpha=...) -> distorted:
    """ """

@overload
def estimateNewCameraMatrixForUndistortRectify(K, D, image_size, R, P=..., balance=..., new_size=..., fov_scale=...) -> P:
    """
    @brief Estimates new camera intrinsic matrix for undistortion or rectification.

        @param K Camera intrinsic matrix \f$cameramatrix{K}\f$.
        @param image_size Size of the image
        @param D Input vector of distortion coefficients \f$\distcoeffsfisheye\f$.
        @param R Rectification transformation in the object space: 3x3 1-channel, or vector: 3x1/1x3
        1-channel or 1x1 3-channel
        @param P New camera intrinsic matrix (3x3) or new projection matrix (3x4)
        @param balance Sets the new focal length in range between the min focal length and the max focal
    """

@overload
def estimateNewCameraMatrixForUndistortRectify(K, D, image_size, R, P=..., balance=..., new_size=..., fov_scale=...) -> P:
    """
    @param new_size the new size
    @param fov_scale Divisor for new focal length.
    """

@overload
def initUndistortRectifyMap(K, D, R, P, size, m1type, map1=..., map2=...) -> tuple[map1, map2]:
    """
    @brief Computes undistortion and rectification maps for image transform by #remap. If D is empty zero
    """

@overload
def initUndistortRectifyMap(K, D, R, P, size, m1type, map1=..., map2=...) -> tuple[map1, map2]:
    """

    @param K Camera intrinsic matrix \f$cameramatrix{K}\f$.
    @param D Input vector of distortion coefficients \f$\distcoeffsfisheye\f$.
    @param R Rectification transformation in the object space: 3x3 1-channel, or vector: 3x1/1x3
    1-channel or 1x1 3-channel
    @param P New camera intrinsic matrix (3x3) or new projection matrix (3x4)
    @param size Undistorted image size.
    @param m1type Type of the first output map that can be CV_32FC1 or CV_16SC2 . See #convertMaps
    """

@overload
def initUndistortRectifyMap(K, D, R, P, size, m1type, map1=..., map2=...) -> tuple[map1, map2]:
    """
    @param map1 The first output map.
    @param map2 The second output map.
    """

def projectPoints(objectPoints, rvec, tvec, K, D, imagePoints=..., alpha=..., jacobian=...) -> tuple[imagePoints, jacobian]:
    """
    @overload
    """

@overload
def stereoCalibrate(objectPoints, imagePoints1, imagePoints2, K1, D1, K2, D2, imageSize, R=..., T=..., rvecs=..., tvecs=..., flags=..., criteria=...) -> tuple[retval, K1, D1, K2, D2, R, T, rvecs, tvecs]:
    """
    @brief Performs stereo calibration

        @param objectPoints Vector of vectors of the calibration pattern points.
        @param imagePoints1 Vector of vectors of the projections of the calibration pattern points,
    """

@overload
def stereoCalibrate(objectPoints, imagePoints1, imagePoints2, K1, D1, K2, D2, imageSize, R=..., T=..., rvecs=..., tvecs=..., flags=..., criteria=...) -> tuple[retval, K1, D1, K2, D2, R, T, rvecs, tvecs]:
    """
    @param imagePoints2 Vector of vectors of the projections of the calibration pattern points,
    """

@overload
def stereoCalibrate(objectPoints, imagePoints1, imagePoints2, K1, D1, K2, D2, imageSize, R=..., T=..., rvecs=..., tvecs=..., flags=..., criteria=...) -> tuple[retval, K1, D1, K2, D2, R, T, rvecs, tvecs]:
    """
    @param K1 Input/output first camera intrinsic matrix:
    \f$\vecthreethree{f_x^{(j)}}{0}{c_x^{(j)}}{0}{f_y^{(j)}}{c_y^{(j)}}{0}{0}{1}\f$ , \f$j = 0,\, 1\f$ . If
    """

@overload
def stereoCalibrate(objectPoints, imagePoints1, imagePoints2, K1, D1, K2, D2, imageSize, R=..., T=..., rvecs=..., tvecs=..., flags=..., criteria=...) -> tuple[retval, K1, D1, K2, D2, R, T, rvecs, tvecs]:
    """ """

@overload
def stereoCalibrate(objectPoints, imagePoints1, imagePoints2, K1, D1, K2, D2, imageSize, R=..., T=..., rvecs=..., tvecs=..., flags=..., criteria=...) -> tuple[retval, K1, D1, K2, D2, R, T, rvecs, tvecs]:
    """
    @param D1 Input/output vector of distortion coefficients \f$\distcoeffsfisheye\f$ of 4 elements.
    @param K2 Input/output second camera intrinsic matrix. The parameter is similar to K1 .
    @param D2 Input/output lens distortion coefficients for the second camera. The parameter is
    """

@overload
def stereoCalibrate(objectPoints, imagePoints1, imagePoints2, K1, D1, K2, D2, imageSize, R=..., T=..., rvecs=..., tvecs=..., flags=..., criteria=...) -> tuple[retval, K1, D1, K2, D2, R, T, rvecs, tvecs]:
    """
    @param imageSize Size of the image used only to initialize camera intrinsic matrix.
    @param R Output rotation matrix between the 1st and the 2nd camera coordinate systems.
    @param T Output translation vector between the coordinate systems of the cameras.
    @param rvecs Output vector of rotation vectors ( @ref Rodrigues ) estimated for each pattern view in the
    """

@overload
def stereoCalibrate(objectPoints, imagePoints1, imagePoints2, K1, D1, K2, D2, imageSize, R=..., T=..., rvecs=..., tvecs=..., flags=..., criteria=...) -> tuple[retval, K1, D1, K2, D2, R, T, rvecs, tvecs]:
    """ """

@overload
def stereoCalibrate(objectPoints, imagePoints1, imagePoints2, K1, D1, K2, D2, imageSize, R=..., T=..., rvecs=..., tvecs=..., flags=..., criteria=...) -> tuple[retval, K1, D1, K2, D2, R, T, rvecs, tvecs]:
    """ """

@overload
def stereoCalibrate(objectPoints, imagePoints1, imagePoints2, K1, D1, K2, D2, imageSize, R=..., T=..., rvecs=..., tvecs=..., flags=..., criteria=...) -> tuple[retval, K1, D1, K2, D2, R, T, rvecs, tvecs]:
    """ """

@overload
def stereoCalibrate(objectPoints, imagePoints1, imagePoints2, K1, D1, K2, D2, imageSize, R=..., T=..., rvecs=..., tvecs=..., flags=..., criteria=...) -> tuple[retval, K1, D1, K2, D2, R, T, rvecs, tvecs]:
    """ """

@overload
def stereoCalibrate(objectPoints, imagePoints1, imagePoints2, K1, D1, K2, D2, imageSize, R=..., T=..., rvecs=..., tvecs=..., flags=..., criteria=...) -> tuple[retval, K1, D1, K2, D2, R, T, rvecs, tvecs]:
    """ """

@overload
def stereoCalibrate(objectPoints, imagePoints1, imagePoints2, K1, D1, K2, D2, imageSize, R=..., T=..., rvecs=..., tvecs=..., flags=..., criteria=...) -> tuple[retval, K1, D1, K2, D2, R, T, rvecs, tvecs]:
    """
    @param tvecs Output vector of translation vectors estimated for each pattern view, see parameter description
    """

@overload
def stereoCalibrate(objectPoints, imagePoints1, imagePoints2, K1, D1, K2, D2, imageSize, R=..., T=..., rvecs=..., tvecs=..., flags=..., criteria=...) -> tuple[retval, K1, D1, K2, D2, R, T, rvecs, tvecs]:
    """
    @param flags Different flags that may be zero or a combination of the following values:
    -    @ref fisheye::CALIB_FIX_INTRINSIC  Fix K1, K2? and D1, D2? so that only R, T matrices
    """

@overload
def stereoCalibrate(objectPoints, imagePoints1, imagePoints2, K1, D1, K2, D2, imageSize, R=..., T=..., rvecs=..., tvecs=..., flags=..., criteria=...) -> tuple[retval, K1, D1, K2, D2, R, T, rvecs, tvecs]:
    """
    -    @ref fisheye::CALIB_USE_INTRINSIC_GUESS  K1, K2 contains valid initial values of
    """

@overload
def stereoCalibrate(objectPoints, imagePoints1, imagePoints2, K1, D1, K2, D2, imageSize, R=..., T=..., rvecs=..., tvecs=..., flags=..., criteria=...) -> tuple[retval, K1, D1, K2, D2, R, T, rvecs, tvecs]:
    """ """

@overload
def stereoCalibrate(objectPoints, imagePoints1, imagePoints2, K1, D1, K2, D2, imageSize, R=..., T=..., rvecs=..., tvecs=..., flags=..., criteria=...) -> tuple[retval, K1, D1, K2, D2, R, T, rvecs, tvecs]:
    """
    -    @ref fisheye::CALIB_RECOMPUTE_EXTRINSIC  Extrinsic will be recomputed after each iteration
    """

@overload
def stereoCalibrate(objectPoints, imagePoints1, imagePoints2, K1, D1, K2, D2, imageSize, R=..., T=..., rvecs=..., tvecs=..., flags=..., criteria=...) -> tuple[retval, K1, D1, K2, D2, R, T, rvecs, tvecs]:
    """
    -    @ref fisheye::CALIB_CHECK_COND  The functions will check validity of condition number.
    -    @ref fisheye::CALIB_FIX_SKEW  Skew coefficient (alpha) is set to zero and stay zero.
    -   @ref fisheye::CALIB_FIX_K1,..., @ref fisheye::CALIB_FIX_K4 Selected distortion coefficients are set to zeros and stay
    """

@overload
def stereoCalibrate(objectPoints, imagePoints1, imagePoints2, K1, D1, K2, D2, imageSize, R=..., T=..., rvecs=..., tvecs=..., flags=..., criteria=...) -> tuple[retval, K1, D1, K2, D2, R, T, rvecs, tvecs]:
    """
    @param criteria Termination criteria for the iterative optimization algorithm.
    """

@overload
def stereoCalibrate(objectPoints, imagePoints1, imagePoints2, K1, D1, K2, D2, imageSize, R=..., T=..., rvecs=..., tvecs=..., flags=..., criteria=...) -> tuple[retval, K1, D1, K2, D2, R, T, rvecs, tvecs]:
    """
    .
    """

@overload
def stereoRectify(K1, D1, K2, D2, imageSize, R, tvec, flags, R1=..., R2=..., P1=..., P2=..., Q=..., newImageSize=..., balance=..., fov_scale=...) -> tuple[R1, R2, P1, P2, Q]:
    """
    @brief Stereo rectification for fisheye camera model

        @param K1 First camera intrinsic matrix.
        @param D1 First camera distortion parameters.
        @param K2 Second camera intrinsic matrix.
        @param D2 Second camera distortion parameters.
        @param imageSize Size of the image used for stereo calibration.
        @param R Rotation matrix between the coordinate systems of the first and the second
    """

@overload
def stereoRectify(K1, D1, K2, D2, imageSize, R, tvec, flags, R1=..., R2=..., P1=..., P2=..., Q=..., newImageSize=..., balance=..., fov_scale=...) -> tuple[R1, R2, P1, P2, Q]:
    """
    @param tvec Translation vector between coordinate systems of the cameras.
    @param R1 Output 3x3 rectification transform (rotation matrix) for the first camera.
    @param R2 Output 3x3 rectification transform (rotation matrix) for the second camera.
    @param P1 Output 3x4 projection matrix in the new (rectified) coordinate systems for the first
    """

@overload
def stereoRectify(K1, D1, K2, D2, imageSize, R, tvec, flags, R1=..., R2=..., P1=..., P2=..., Q=..., newImageSize=..., balance=..., fov_scale=...) -> tuple[R1, R2, P1, P2, Q]:
    """
    @param P2 Output 3x4 projection matrix in the new (rectified) coordinate systems for the second
    """

@overload
def stereoRectify(K1, D1, K2, D2, imageSize, R, tvec, flags, R1=..., R2=..., P1=..., P2=..., Q=..., newImageSize=..., balance=..., fov_scale=...) -> tuple[R1, R2, P1, P2, Q]:
    """
    @param Q Output \f$4 \times 4\f$ disparity-to-depth mapping matrix (see #reprojectImageTo3D ).
    @param flags Operation flags that may be zero or @ref fisheye::CALIB_ZERO_DISPARITY . If the flag is set,
    """

@overload
def stereoRectify(K1, D1, K2, D2, imageSize, R, tvec, flags, R1=..., R2=..., P1=..., P2=..., Q=..., newImageSize=..., balance=..., fov_scale=...) -> tuple[R1, R2, P1, P2, Q]:
    """ """

@overload
def stereoRectify(K1, D1, K2, D2, imageSize, R, tvec, flags, R1=..., R2=..., P1=..., P2=..., Q=..., newImageSize=..., balance=..., fov_scale=...) -> tuple[R1, R2, P1, P2, Q]:
    """ """

@overload
def stereoRectify(K1, D1, K2, D2, imageSize, R, tvec, flags, R1=..., R2=..., P1=..., P2=..., Q=..., newImageSize=..., balance=..., fov_scale=...) -> tuple[R1, R2, P1, P2, Q]:
    """ """

@overload
def stereoRectify(K1, D1, K2, D2, imageSize, R, tvec, flags, R1=..., R2=..., P1=..., P2=..., Q=..., newImageSize=..., balance=..., fov_scale=...) -> tuple[R1, R2, P1, P2, Q]:
    """
    @param newImageSize New image resolution after rectification. The same size should be passed to
    #initUndistortRectifyMap (see the stereo_calib.cpp sample in OpenCV samples directory). When (0,0)
    """

@overload
def stereoRectify(K1, D1, K2, D2, imageSize, R, tvec, flags, R1=..., R2=..., P1=..., P2=..., Q=..., newImageSize=..., balance=..., fov_scale=...) -> tuple[R1, R2, P1, P2, Q]:
    """ """

@overload
def stereoRectify(K1, D1, K2, D2, imageSize, R, tvec, flags, R1=..., R2=..., P1=..., P2=..., Q=..., newImageSize=..., balance=..., fov_scale=...) -> tuple[R1, R2, P1, P2, Q]:
    """
    @param balance Sets the new focal length in range between the min focal length and the max focal
    """

@overload
def stereoRectify(K1, D1, K2, D2, imageSize, R, tvec, flags, R1=..., R2=..., P1=..., P2=..., Q=..., newImageSize=..., balance=..., fov_scale=...) -> tuple[R1, R2, P1, P2, Q]:
    """
    @param fov_scale Divisor for new focal length.
    """

@overload
def undistortImage(distorted, K, D, undistorted=..., Knew=..., new_size=...) -> undistorted:
    """
    @brief Transforms an image to compensate for fisheye lens distortion.

        @param distorted image with fisheye lens distortion.
        @param undistorted Output image with compensated fisheye lens distortion.
        @param K Camera intrinsic matrix \f$cameramatrix{K}\f$.
        @param D Input vector of distortion coefficients \f$\distcoeffsfisheye\f$.
        @param Knew Camera intrinsic matrix of the distorted image. By default, it is the identity matrix but you
    """

@overload
def undistortImage(distorted, K, D, undistorted=..., Knew=..., new_size=...) -> undistorted:
    """
    @param new_size the new size
    """

@overload
def undistortImage(distorted, K, D, undistorted=..., Knew=..., new_size=...) -> undistorted:
    """ """

@overload
def undistortImage(distorted, K, D, undistorted=..., Knew=..., new_size=...) -> undistorted:
    """
    (with bilinear interpolation). See the former function for details of the transformation being
    """

@overload
def undistortImage(distorted, K, D, undistorted=..., Knew=..., new_size=...) -> undistorted:
    """ """

@overload
def undistortImage(distorted, K, D, undistorted=..., Knew=..., new_size=...) -> undistorted:
    """
    -   a\) result of undistort of perspective camera model (all possible coefficients (k_1, k_2, k_3,
         k_4, k_5, k_6) of distortion were optimized under calibration)
     -   b\) result of #fisheye::undistortImage of fisheye camera model (all possible coefficients (k_1, k_2,
         k_3, k_4) of fisheye distortion were optimized under calibration)
     -   c\) original image was captured with fisheye lens
    """

@overload
def undistortImage(distorted, K, D, undistorted=..., Knew=..., new_size=...) -> undistorted:
    """ """

@overload
def undistortImage(distorted, K, D, undistorted=..., Knew=..., new_size=...) -> undistorted:
    """

    ![image](pics/fisheye_undistorted.jpg)
    """

@overload
def undistortPoints(distorted, K, D, undistorted=..., R=..., P=..., criteria=...) -> undistorted:
    """
    @brief Undistorts 2D points using fisheye model

        @param distorted Array of object points, 1xN/Nx1 2-channel (or vector\<Point2f\> ), where N is the
    """

@overload
def undistortPoints(distorted, K, D, undistorted=..., R=..., P=..., criteria=...) -> undistorted:
    """
    @param K Camera intrinsic matrix \f$cameramatrix{K}\f$.
    @param D Input vector of distortion coefficients \f$\distcoeffsfisheye\f$.
    @param R Rectification transformation in the object space: 3x3 1-channel, or vector: 3x1/1x3
    1-channel or 1x1 3-channel
    @param P New camera intrinsic matrix (3x3) or new projection matrix (3x4)
    @param criteria Termination criteria
    @param undistorted Output array of image points, 1xN/Nx1 2-channel, or vector\<Point2f\> .
    """

CALIB_CHECK_COND: Final[int]
CALIB_FIX_FOCAL_LENGTH: Final[int]
CALIB_FIX_INTRINSIC: Final[int]
CALIB_FIX_K1: Final[int]
CALIB_FIX_K2: Final[int]
CALIB_FIX_K3: Final[int]
CALIB_FIX_K4: Final[int]
CALIB_FIX_PRINCIPAL_POINT: Final[int]
CALIB_FIX_SKEW: Final[int]
CALIB_RECOMPUTE_EXTRINSIC: Final[int]
CALIB_USE_INTRINSIC_GUESS: Final[int]
CALIB_ZERO_DISPARITY: Final[int]



from typing import Any, TypeAlias

from .. import functions as cv2

retval: TypeAlias = Any

class HfsSegment(cv2.Algorithm):
    def getMinRegionSizeI(self) -> retval:
        """"""

    def getMinRegionSizeII(self) -> retval:
        """"""

    def getNumSlicIter(self) -> retval:
        """"""

    def getSegEgbThresholdI(self) -> retval:
        """"""

    def getSegEgbThresholdII(self) -> retval:
        """"""

    def getSlicSpixelSize(self) -> retval:
        """"""

    def getSpatialWeight(self) -> retval:
        """"""

    def performSegmentCpu(self, src, ifDraw=...) -> retval:
        """
        @brief do segmentation with cpu
        * This method is only implemented for reference.
        * It is highly NOT recommanded to use it.
        """

    def performSegmentGpu(self, src, ifDraw=...) -> retval:
        """
        @brief do segmentation gpu
        * @param src: the input image
        * @param ifDraw: if draw the image in the returned Mat. if this parameter is false, * then the content of the returned Mat is a matrix of index, describing the region * each pixel belongs to. And it's data type is CV_16U. If this parameter is true, * then the returned Mat is a segmented picture, and color of each region is the * average color of all pixels in that region. And it's data type is the same as * the input image
        """

    def setMinRegionSizeI(self, n) -> None:
        """
        @brief: set and get the parameter minRegionSizeI.
        * This parameter is used in the second stage
        * mentioned above. After the EGB segmentation, regions that have fewer
        * pixels then this parameter will be merged into it's adjacent region.
        """

    def setMinRegionSizeII(self, n) -> None:
        """
        @brief: set and get the parameter minRegionSizeII.
        * This parameter is used in the third stage
        * mentioned above. It serves the same purpose as minRegionSizeI
        """

    def setNumSlicIter(self, n) -> None:
        """
        @brief: set and get the parameter numSlicIter.
        * This parameter is used in the first stage. It
        * describes how many iteration to perform when executing SLIC.
        """

    def setSegEgbThresholdI(self, c) -> None:
        """
        @brief: set and get the parameter segEgbThresholdI.
        * This parameter is used in the second stage mentioned above.
        * It is a constant used to threshold weights of the edge when merging
        * adjacent nodes when applying EGB algorithm. The segmentation result
        * tends to have more regions remained if this value is large and vice versa.
        """

    def setSegEgbThresholdII(self, c) -> None:
        """
        @brief: set and get the parameter segEgbThresholdII.
        * This parameter is used in the third stage
        * mentioned above. It serves the same purpose as segEgbThresholdI.
        * The segmentation result tends to have more regions remained if
        * this value is large and vice versa.
        """

    def setSlicSpixelSize(self, n) -> None:
        """
        @brief: set and get the parameter slicSpixelSize.
        * This parameter is used in the first stage mentioned
        * above(the SLIC stage). It describes the size of each
        * superpixel when initializing SLIC. Every superpixel
        * approximately has \f$slicSpixelSize \times slicSpixelSize\f$
        * pixels in the beginning.
        """

    def setSpatialWeight(self, w) -> None:
        """
        @brief: set and get the parameter spatialWeight.
        * This parameter is used in the first stage
        * mentioned above(the SLIC stage). It describes how important is the role
        * of position when calculating the distance between each pixel and it's
        * center. The exact formula to calculate the distance is
        * \f$colorDistance + spatialWeight \times spatialDistance\f$.
        * The segmentation result tends to have more local consistency
        * if this value is larger.
        """

    def create(self, height, width, segEgbThresholdI=..., minRegionSizeI=..., segEgbThresholdII=..., minRegionSizeII=..., spatialWeight=..., slicSpixelSize=..., numSlicIter=...) -> retval:
        """
        @brief: create a hfs object
        * @param height: the height of the input image
        * @param width: the width of the input image
        * @param segEgbThresholdI: parameter segEgbThresholdI
        * @param minRegionSizeI: parameter minRegionSizeI
        * @param segEgbThresholdII: parameter segEgbThresholdII
        * @param minRegionSizeII: parameter minRegionSizeII
        * @param spatialWeight: parameter spatialWeight
        * @param slicSpixelSize: parameter slicSpixelSize
        * @param numSlicIter: parameter numSlicIter
        """

def HfsSegment_create(height, width, segEgbThresholdI=..., minRegionSizeI=..., segEgbThresholdII=..., minRegionSizeII=..., spatialWeight=..., slicSpixelSize=..., numSlicIter=...) -> retval:
    """
    @brief: create a hfs object
    * @param height: the height of the input image
    * @param width: the width of the input image
    * @param segEgbThresholdI: parameter segEgbThresholdI
    * @param minRegionSizeI: parameter minRegionSizeI
    * @param segEgbThresholdII: parameter segEgbThresholdII
    * @param minRegionSizeII: parameter minRegionSizeII
    * @param spatialWeight: parameter spatialWeight
    * @param slicSpixelSize: parameter slicSpixelSize
    * @param numSlicIter: parameter numSlicIter
    """



from typing import Any, TypeAlias

from .. import functions as cv2

_binaryMap: TypeAlias = Any
saliencyMap: TypeAlias = Any

retval: TypeAlias = Any

class MotionSaliency(Saliency): ...

class MotionSaliencyBinWangApr2014(MotionSaliency):
    def computeSaliency(self, image, saliencyMap=...) -> tuple[retval, saliencyMap]:
        """"""

    def getImageHeight(self) -> retval:
        """"""

    def getImageWidth(self) -> retval:
        """"""

    def init(self) -> retval:
        """
        @brief This function allows the correct initialization of all data structures that will be used by the
        algorithm.
        """

    def setImageHeight(self, val) -> None:
        """"""

    def setImageWidth(self, val) -> None:
        """"""

    def setImagesize(self, W, H) -> None:
        """
        @brief This is a utility function that allows to set the correct size (taken from the input image) in the
        corresponding variables that will be used to size the data structures of the algorithm.
        @param W width of input image
        @param H height of input image
        """

    def create(self) -> retval:
        """"""

class Objectness(Saliency): ...

class ObjectnessBING(Objectness):
    def computeSaliency(self, image, saliencyMap=...) -> tuple[retval, saliencyMap]:
        """"""

    def getBase(self) -> retval:
        """"""

    def getNSS(self) -> retval:
        """"""

    def getW(self) -> retval:
        """"""

    def getobjectnessValues(self) -> retval:
        """
        @brief Return the list of the rectangles' objectness value,

        in the same order as the *vector\<Vec4i\> objectnessBoundingBox* returned by the algorithm (in
        computeSaliencyImpl function). The bigger value these scores are, it is more likely to be an
        object window.
        """

    def read(self) -> None:
        """"""

    def setBBResDir(self, resultsDir) -> None:
        """
        @brief This is a utility function that allows to set an arbitrary path in which the algorithm will save the
        optional results

        (ie writing on file the total number and the list of rectangles returned by objectess, one for
        each row).
        @param resultsDir results' folder path
        """

    def setBase(self, val) -> None:
        """"""

    def setNSS(self, val) -> None:
        """"""

    def setTrainingPath(self, trainingPath) -> None:
        """
        @brief This is a utility function that allows to set the correct path from which the algorithm will load
        the trained model.
        @param trainingPath trained model path
        """

    def setW(self, val) -> None:
        """"""

    def write(self) -> None:
        """"""

    def create(self) -> retval:
        """"""

class Saliency(cv2.Algorithm):
    def computeSaliency(self, image, saliencyMap=...) -> tuple[retval, saliencyMap]:
        """
        * \brief Compute the saliency
        * \param image        The image.
        * \param saliencyMap      The computed saliency map.
        * \return true if the saliency map is computed, false otherwise
        """

class StaticSaliency(Saliency):
    def computeBinaryMap(self, _saliencyMap, _binaryMap=...) -> tuple[retval, _binaryMap]:
        """
        @brief This function perform a binary map of given saliency map. This is obtained in this
        way:

        In a first step, to improve the definition of interest areas and facilitate identification of
        targets, a segmentation by clustering is performed, using *K-means algorithm*. Then, to gain a
        binary representation of clustered saliency map, since values of the map can vary according to
        the characteristics of frame under analysis, it is not convenient to use a fixed threshold. So,
        *Otsu's algorithm* is used, which assumes that the image to be thresholded contains two classes
        of pixels or bi-modal histograms (e.g. foreground and back-ground pixels); later on, the
        algorithm calculates the optimal threshold separating those two classes, so that their
        intra-class variance is minimal.

        @param _saliencyMap the saliency map obtained through one of the specialized algorithms
        @param _binaryMap the binary map
        """

class StaticSaliencyFineGrained(StaticSaliency):
    def computeSaliency(self, image, saliencyMap=...) -> tuple[retval, saliencyMap]:
        """"""

    def create(self) -> retval:
        """"""

class StaticSaliencySpectralResidual(StaticSaliency):
    def computeSaliency(self, image, saliencyMap=...) -> tuple[retval, saliencyMap]:
        """"""

    def getImageHeight(self) -> retval:
        """"""

    def getImageWidth(self) -> retval:
        """"""

    def read(self, fn) -> None:
        """"""

    def setImageHeight(self, val) -> None:
        """"""

    def setImageWidth(self, val) -> None:
        """"""

    def create(self) -> retval:
        """"""

def MotionSaliencyBinWangApr2014_create() -> retval:
    """
    .
    """

def ObjectnessBING_create() -> retval:
    """
    .
    """

def StaticSaliencyFineGrained_create() -> retval:
    """
    .
    """

def StaticSaliencySpectralResidual_create() -> retval:
    """
    .
    """



import builtins
from typing import Any, Final, overload, TypeAlias

from .. import functions as cv2

timings: TypeAlias = Any
layersTypes: TypeAlias = Any
images_: TypeAlias = Any
inLayersShapes: TypeAlias = Any
outputBlobs: TypeAlias = Any
layersIds: TypeAlias = Any
outputs: TypeAlias = Any
internals: TypeAlias = Any
outs: TypeAlias = Any
detections: TypeAlias = Any
blobs: TypeAlias = Any
weights: TypeAlias = Any
confidences: TypeAlias = Any
zeropoints: TypeAlias = Any
updated_scores: TypeAlias = Any
scales: TypeAlias = Any
classId: TypeAlias = Any
boxes: TypeAlias = Any
conf: TypeAlias = Any
outLayersShapes: TypeAlias = Any
mask: TypeAlias = Any
indices: TypeAlias = Any
classIds: TypeAlias = Any
results: TypeAlias = Any
dst: TypeAlias = Any
retval: TypeAlias = Any

class ClassificationModel(Model):
    def classify(self, frame) -> tuple[classId, conf]:
        """
        @overload
        """

    def getEnableSoftmaxPostProcessing(self) -> retval:
        """
        * @brief Get enable/disable softmax post processing option.
        *
        * This option defaults to false, softmax post processing is not applied within the classify() function.
        """

    def setEnableSoftmaxPostProcessing(self, enable) -> retval:
        """
        * @brief Set enable/disable softmax post processing option.
        *
        * If this option is true, softmax is applied after forward inference within the classify() function
        * to convert the confidences range to [0.0-1.0].
        * This function allows you to toggle this behavior.
        * Please turn true when not contain softmax layer in model.
        * @param[in] enable Set enable softmax post processing within the classify() function.
        """

class DetectionModel(Model):
    def detect(self, frame, confThreshold=..., nmsThreshold=...) -> tuple[classIds, confidences, boxes]:
        """
        @brief Given the @p input frame, create input blob, run net and return result detections.
        *  @param[in]  frame  The input image.
        *  @param[out] classIds Class indexes in result detection.
        *  @param[out] confidences A set of corresponding confidences.
        *  @param[out] boxes A set of bounding boxes.
        *  @param[in] confThreshold A threshold used to filter boxes by confidences.
        *  @param[in] nmsThreshold A threshold used in non maximum suppression.
        """

    def getNmsAcrossClasses(self) -> retval:
        """
        * @brief Getter for nmsAcrossClasses. This variable defaults to false,
        * such that when non max suppression is used during the detect() function, it will do so only per-class
        """

    def setNmsAcrossClasses(self, value) -> retval:
        """
        * @brief nmsAcrossClasses defaults to false,
        * such that when non max suppression is used during the detect() function, it will do so per-class.
        * This function allows you to toggle this behaviour.
        * @param[in] value The new value for nmsAcrossClasses
        """

class DictValue:
    def getIntValue(self, idx=...) -> retval:
        """"""

    def getRealValue(self, idx=...) -> retval:
        """"""

    def getStringValue(self, idx=...) -> retval:
        """"""

    def isInt(self) -> retval:
        """"""

    def isReal(self) -> retval:
        """"""

    def isString(self) -> retval:
        """"""

class KeypointsModel(Model):
    def estimate(self, frame, thresh=...) -> retval:
        """
        @brief Given the @p input frame, create input blob, run net
        *  @param[in]  frame  The input image.
        *  @param thresh minimum confidence threshold to select a keypoint *  @returns a vector holding the x and y coordinates of each detected keypoint *
        """

class Layer(cv2.Algorithm):
    def finalize(self, inputs, outputs=...) -> outputs:
        """
        @brief Computes and sets internal parameters according to inputs, outputs and blobs.
        *  @param[in]  inputs  vector of already allocated input blobs
        *  @param[out] outputs vector of already allocated output blobs * * If this method is called after network has allocated all memory for input and output blobs * and before inferencing.
        """

    def outputNameToIndex(self, outputName) -> retval:
        """
        @brief Returns index of output blob in output array.
        *  @see inputNameToIndex()
        """

    def run(self, inputs, internals, outputs=...) -> tuple[outputs, internals]:
        """
        @brief Allocates layer and computes output.
        *  @deprecated This method will be removed in the future release.
        """

class Model:
    def predict(self, frame, outs=...) -> outs:
        """
        @brief Given the @p input frame, create input blob, run net and return the output @p blobs.
        *  @param[in]  frame  The input image.
        *  @param[out] outs Allocated output blobs, which will store results of the computation.
        """

    def setInputCrop(self, crop) -> retval:
        """
        @brief Set flag crop for frame.
        *  @param[in] crop Flag which indicates whether image will be cropped after resize or not.
        """

    def setInputMean(self, mean) -> retval:
        """
        @brief Set mean value for frame.
        *  @param[in] mean Scalar with mean values which are subtracted from channels.
        """

    def setInputParams(self, scale=..., size=..., mean=..., swapRB=..., crop=...) -> None:
        """
        @brief Set preprocessing parameters for frame.
        *  @param[in] size New input size.
        *  @param[in] mean Scalar with mean values which are subtracted from channels.
        *  @param[in] scale Multiplier for frame values.
        *  @param[in] swapRB Flag which indicates that swap first and last channels.
        *  @param[in] crop Flag which indicates whether image will be cropped after resize or not. *  blob(n, c, y, x) = scale * resize( frame(y, x, c) ) - mean(c) )
        """

    def setInputScale(self, scale) -> retval:
        """
        @brief Set scalefactor value for frame.
        *  @param[in] scale Multiplier for frame values.
        """

    @overload
    def setInputSize(self, size) -> retval:
        """
        @brief Set input size for frame.
        *  @param[in] size New input size. *  @note If shape of the new blob less than 0, then frame size not change.
        """

    @overload
    def setInputSize(self, width, height) -> retval:
        """
        @overload
        *  @param[in] width New input width.
        *  @param[in] height New input height.
        """

    def setInputSwapRB(self, swapRB) -> retval:
        """
        @brief Set flag swapRB for frame.
        *  @param[in] swapRB Flag which indicates that swap first and last channels.
        """

    def setPreferableBackend(self, backendId) -> retval:
        """"""

    def setPreferableTarget(self, targetId) -> retval:
        """"""

class Net:
    def connect(self, outPin, inpPin) -> None:
        """
        @brief Connects output of the first layer to input of the second layer.
        *  @param outPin descriptor of the first layer output.
        *  @param inpPin descriptor of the second layer input. * * Descriptors have the following template <DFN>&lt;layer_name&gt;[.input_number]</DFN>: * - the first part of the template <DFN>layer_name</DFN> is string name of the added layer. *   If this part is empty then the network input pseudo layer will be used; * - the second optional part of the template <DFN>input_number</DFN> *   is either number of the layer input, either label one. *   If this part is omitted then the first layer input will be used. * *  @see setNetInputs(), Layer::inputNameToIndex(), Layer::outputNameToIndex()
        """

    def dump(self) -> retval:
        """
        @brief Dump net to String
        *  @returns String with structure, hyperparameters, backend, target and fusion
        *  Call method after setInput(). To see correct backend, target and fusion run after forward().
        """

    def dumpToFile(self, path) -> None:
        """
        @brief Dump net structure, hyperparameters, backend, target and fusion to dot file
        *  @param path   path to output file with .dot extension *  @see dump()
        """

    def empty(self) -> retval:
        """
        Returns true if there are no layers in the network.
        """

    def enableFusion(self, fusion) -> None:
        """
        @brief Enables or disables layer fusion in the network.
        * @param fusion true to enable the fusion, false to disable. The fusion is enabled by default.
        """

    def enableWinograd(self, useWinograd) -> None:
        """
        @brief Enables or disables the Winograd compute branch. The Winograd compute branch can speed up
        * 3x3 Convolution at a small loss of accuracy.
        * @param useWinograd true to enable the Winograd compute branch. The default is true.
        """

    @overload
    def forward(self, outputName=...) -> retval:
        """
        @brief Runs forward pass to compute output of layer with name @p outputName.
        *  @param outputName name for layer which output is needed to get *  @return blob for first output of specified layer. *  @details By default runs forward pass for the whole network.
        """

    @overload
    def forward(self, outputBlobs=..., outputName=...) -> outputBlobs:
        """
        @brief Runs forward pass to compute output of layer with name @p outputName.
        *  @param outputBlobs contains all output blobs for specified layer.
        *  @param outputName name for layer which output is needed to get *  @details If @p outputName is empty, runs forward pass for the whole network.
        """

    def forward(self, outBlobNames, outputBlobs=...) -> outputBlobs:
        """
        @brief Runs forward pass to compute outputs of layers listed in @p outBlobNames.
        *  @param outputBlobs contains blobs for first outputs of specified layers.
        *  @param outBlobNames names for layers which outputs are needed to get
        """

    def forwardAndRetrieve(self, outBlobNames) -> outputBlobs:
        """
        @brief Runs forward pass to compute outputs of layers listed in @p outBlobNames.
        *  @param outputBlobs contains all output blobs for each layer specified in @p outBlobNames.
        *  @param outBlobNames names for layers which outputs are needed to get
        """

    def forwardAsync(self, outputName=...) -> retval:
        """
        @brief Runs forward pass to compute output of layer with name @p outputName.
        *  @param outputName name for layer which output is needed to get *  @details By default runs forward pass for the whole network. * *  This is an asynchronous version of forward(const String&). *  dnn::DNN_BACKEND_INFERENCE_ENGINE backend is required.
        """

    @overload
    def getFLOPS(self, netInputShapes) -> retval:
        """
        @brief Computes FLOP for whole loaded model with specified input shapes.
        * @param netInputShapes vector of shapes for all net inputs. * @returns computed FLOP.
        """

    @overload
    def getFLOPS(self, netInputShape) -> retval:
        """
        @overload
        """

    @overload
    def getFLOPS(self, layerId, netInputShapes) -> retval:
        """
        @overload
        """

    @overload
    def getFLOPS(self, layerId, netInputShape) -> retval:
        """
        @overload
        """

    def getInputDetails(self) -> tuple[scales, zeropoints]:
        """
        @brief Returns input scale and zeropoint for a quantized Net.
        *  @param scales output parameter for returning input scales.
        *  @param zeropoints output parameter for returning input zeropoints.
        """

    @overload
    def getLayer(self, layerId) -> retval:
        """
        @brief Returns pointer to layer with specified id or name which the network use.
        """

    @overload
    def getLayer(self, layerName) -> retval:
        """
        @overload
        *  @deprecated Use int getLayerId(const String &layer)
        """

    def getLayerId(self, layer) -> retval:
        """
        @brief Converts string name of the layer to the integer identifier.
        *  @returns id of the layer, or -1 if the layer wasn't found.
        """

    def getLayerNames(self) -> retval:
        """"""

    def getLayerTypes(self) -> layersTypes:
        """
        @brief Returns list of types for layer used in model.
        * @param layersTypes output parameter for returning types.
        """

    def getLayersCount(self, layerType) -> retval:
        """
        @brief Returns count of layers of specified type.
        * @param layerType type. * @returns count of layers
        """

    @overload
    def getLayersShapes(self, netInputShapes) -> tuple[layersIds, inLayersShapes, outLayersShapes]:
        """
        @brief Returns input and output shapes for all layers in loaded model;
        *  preliminary inferencing isn't necessary.
        *  @param netInputShapes shapes for all input blobs in net input layer.
        *  @param layersIds output parameter for layer IDs.
        *  @param inLayersShapes output parameter for input layers shapes; * order is the same as in layersIds
        *  @param outLayersShapes output parameter for output layers shapes; * order is the same as in layersIds
        """

    @overload
    def getLayersShapes(self, netInputShape) -> tuple[layersIds, inLayersShapes, outLayersShapes]:
        """
        @overload
        """

    @overload
    def getMemoryConsumption(self, netInputShape) -> tuple[weights, blobs]:
        """
        @overload
        """

    @overload
    def getMemoryConsumption(self, layerId, netInputShapes) -> tuple[weights, blobs]:
        """
        @overload
        """

    @overload
    def getMemoryConsumption(self, layerId, netInputShape) -> tuple[weights, blobs]:
        """
        @overload
        """

    def getOutputDetails(self) -> tuple[scales, zeropoints]:
        """
        @brief Returns output scale and zeropoint for a quantized Net.
        *  @param scales output parameter for returning output scales.
        *  @param zeropoints output parameter for returning output zeropoints.
        """

    @overload
    def getParam(self, layer, numParam=...) -> retval:
        """
        @brief Returns parameter blob of the layer.
        *  @param layer name or id of the layer.
        *  @param numParam index of the layer parameter in the Layer::blobs array. *  @see Layer::blobs
        """

    @overload
    def getParam(self, layerName, numParam=...) -> retval:
        """"""

    def getPerfProfile(self) -> tuple[retval, timings]:
        """
        @brief Returns overall time for inference and timings (in ticks) for layers.
        *
        * Indexes in returned vector correspond to layers ids. Some layers can be fused with others,
        * in this case zero ticks count will be return for that skipped layers. Supported by DNN_BACKEND_OPENCV on DNN_TARGET_CPU only.
        *
        * @param[out] timings vector for tick timings for all layers. * @return overall ticks for model inference.
        """

    def getUnconnectedOutLayers(self) -> retval:
        """
        @brief Returns indexes of layers with unconnected outputs.
        *
        * FIXIT: Rework API to registerOutput() approach, deprecate this call
        """

    def getUnconnectedOutLayersNames(self) -> retval:
        """
        @brief Returns names of layers with unconnected outputs.
        *
        * FIXIT: Rework API to registerOutput() approach, deprecate this call
        """

    def quantize(self, calibData, inputsDtype, outputsDtype, perChannel=...) -> retval:
        """
        @brief Returns a quantized Net from a floating-point Net.
        *  @param calibData Calibration data to compute the quantization parameters.
        *  @param inputsDtype Datatype of quantized net's inputs. Can be CV_32F or CV_8S.
        *  @param outputsDtype Datatype of quantized net's outputs. Can be CV_32F or CV_8S.
        *  @param perChannel Quantization granularity of quantized Net. The default is true, that means quantize model *  in per-channel way (channel-wise). Set it false to quantize model in per-tensor way (or tensor-wise).
        """

    def setHalideScheduler(self, scheduler) -> None:
        """
        * @brief Compile Halide layers.
        * @param[in] scheduler Path to YAML file with scheduling directives. * @see setPreferableBackend * * Schedule layers that support Halide backend. Then compile them for * specific target. For layers that not represented in scheduling file * or if no manual scheduling used at all, automatic scheduling will be applied.
        """

    def setInput(self, blob, name=..., scalefactor=..., mean=...) -> None:
        """
        @brief Sets the new input value for the network
        *  @param blob        A new blob. Should have CV_32F or CV_8U depth.
        *  @param name        A name of input layer.
        *  @param scalefactor An optional normalization scale.
        *  @param mean        An optional mean subtraction values. *  @see connect(String, String) to know format of the descriptor. * *  If scale or mean values are specified, a final input blob is computed *  as: * \f[input(n,c,h,w) = scalefactor \times (blob(n,c,h,w) - mean_c)\f]
        """

    def setInputShape(self, inputName, shape) -> None:
        """
        @brief Specify shape of network input.
        """

    def setInputsNames(self, inputBlobNames) -> None:
        """
        @brief Sets outputs names of the network input pseudo layer.
        *
        * Each net always has special own the network input pseudo layer with id=0.
        * This layer stores the user blobs only and don't make any computations.
        * In fact, this layer provides the only way to pass user data into the network.
        * As any other layer, this layer can label its outputs and this function provides an easy way to do this.
        """

    @overload
    def setParam(self, layer, numParam, blob) -> None:
        """
        @brief Sets the new value for the learned param of the layer.
        *  @param layer name or id of the layer.
        *  @param numParam index of the layer parameter in the Layer::blobs array.
        *  @param blob the new value. *  @see Layer::blobs *  @note If shape of the new blob differs from the previous shape, *  then the following forward pass may fail.
        """

    @overload
    def setParam(self, layerName, numParam, blob) -> None:
        """"""

    def setPreferableBackend(self, backendId) -> None:
        """
        * @brief Ask network to use specific computation backend where it supported.
        * @param[in] backendId backend identifier. * @see Backend * * If OpenCV is compiled with Intel's Inference Engine library, DNN_BACKEND_DEFAULT * means DNN_BACKEND_INFERENCE_ENGINE. Otherwise it equals to DNN_BACKEND_OPENCV.
        """

    def setPreferableTarget(self, targetId) -> None:
        """
        * @brief Ask network to make computations on specific target device.
        * @param[in] targetId target identifier. * @see Target * * List of supported combinations backend / target: * |                        | DNN_BACKEND_OPENCV | DNN_BACKEND_INFERENCE_ENGINE | DNN_BACKEND_HALIDE |  DNN_BACKEND_CUDA | * |------------------------|--------------------|------------------------------|--------------------|-------------------| * | DNN_TARGET_CPU         |                  + |                            + |                  + |                   | * | DNN_TARGET_OPENCL      |                  + |                            + |                  + |                   | * | DNN_TARGET_OPENCL_FP16 |                  + |                            + |                    |                   | * | DNN_TARGET_MYRIAD      |                    |                            + |                    |                   | * | DNN_TARGET_FPGA        |                    |                            + |                    |                   | * | DNN_TARGET_CUDA        |                    |                              |                    |                 + | * | DNN_TARGET_CUDA_FP16   |                    |                              |                    |                 + | * | DNN_TARGET_HDDL        |                    |                            + |                    |                   |
        """

    @overload
    def readFromModelOptimizer(self, xml, bin) -> retval:
        """
        @brief Create a network from Intel's Model Optimizer intermediate representation (IR).
        *  @param[in] xml XML configuration file with network's topology.
        *  @param[in] bin Binary file with trained weights. *  Networks imported from Intel's Model Optimizer are launched in Intel's Inference Engine *  backend.
        """

    @overload
    def readFromModelOptimizer(self, bufferModelConfig, bufferWeights) -> retval:
        """
        @brief Create a network from Intel's Model Optimizer in-memory buffers with intermediate representation (IR).
        *  @param[in] bufferModelConfig buffer with model's configuration.
        *  @param[in] bufferWeights buffer with model's trained weights. *  @returns Net object.
        """

class SegmentationModel(Model):
    def segment(self, frame, mask=...) -> mask:
        """
        @brief Given the @p input frame, create input blob, run net
        *  @param[in]  frame  The input image.
        *  @param[out] mask Allocated class prediction for each pixel
        """

class TextDetectionModel(Model):
    @overload
    def detect(self, frame) -> tuple[detections, confidences]:
        """
        @brief Performs detection
        *
        * Given the input @p frame, prepare network input, run network inference, post-process network output and return result detections.
        *
        * Each result is quadrangle's 4 points in this order:
        * - bottom-left
        * - top-left
        * - top-right
        * - bottom-right
        *
        * Use cv::getPerspectiveTransform function to retrieve image region without perspective transformations.
        *
        * @note If DL model doesn't support that kind of output then result may be derived from detectTextRectangles() output.
        *
        * @param[in] frame The input image
        * @param[out] detections array with detections' quadrangles (4 points per result)
        * @param[out] confidences array with detection confidences
        """

    @overload
    def detect(self, frame) -> detections:
        """
        @overload
        """

    @overload
    def detectTextRectangles(self, frame) -> tuple[detections, confidences]:
        """
        @brief Performs detection
        *
        * Given the input @p frame, prepare network input, run network inference, post-process network output and return result detections.
        *
        * Each result is rotated rectangle.
        *
        * @note Result may be inaccurate in case of strong perspective transformations.
        *
        * @param[in] frame the input image
        * @param[out] detections array with detections' RotationRect results
        * @param[out] confidences array with detection confidences
        """

    @overload
    def detectTextRectangles(self, frame) -> detections:
        """
        @overload
        """

class TextDetectionModel_DB(TextDetectionModel):
    def getBinaryThreshold(self) -> retval:
        """"""

    def getMaxCandidates(self) -> retval:
        """"""

    def getPolygonThreshold(self) -> retval:
        """"""

    def getUnclipRatio(self) -> retval:
        """"""

    def setBinaryThreshold(self, binaryThreshold) -> retval:
        """"""

    def setMaxCandidates(self, maxCandidates) -> retval:
        """"""

    def setPolygonThreshold(self, polygonThreshold) -> retval:
        """"""

    def setUnclipRatio(self, unclipRatio) -> retval:
        """"""

class TextDetectionModel_EAST(TextDetectionModel):
    def getConfidenceThreshold(self) -> retval:
        """
        * @brief Get the detection confidence threshold
        """

    def getNMSThreshold(self) -> retval:
        """
        * @brief Get the detection confidence threshold
        """

    def setConfidenceThreshold(self, confThreshold) -> retval:
        """
        * @brief Set the detection confidence threshold
        * @param[in] confThreshold A threshold used to filter boxes by confidences
        """

    def setNMSThreshold(self, nmsThreshold) -> retval:
        """
        * @brief Set the detection NMS filter threshold
        * @param[in] nmsThreshold A threshold used in non maximum suppression
        """

class TextRecognitionModel(Model):
    def getDecodeType(self) -> retval:
        """
        * @brief Get the decoding method
        * @return the decoding method
        """

    def getVocabulary(self) -> retval:
        """
        * @brief Get the vocabulary for recognition.
        * @return vocabulary the associated vocabulary
        """

    @overload
    def recognize(self, frame) -> retval:
        """
        * @brief Given the @p input frame, create input blob, run net and return recognition result
        * @param[in] frame The input image * @return The text recognition result
        """

    @overload
    def recognize(self, frame, roiRects) -> results:
        """
        * @brief Given the @p input frame, create input blob, run net and return recognition result
        * @param[in] frame The input image
        * @param[in] roiRects List of text detection regions of interest (cv::Rect, CV_32SC4). ROIs is be cropped as the network inputs
        * @param[out] results A set of text recognition results.
        """

    def setDecodeOptsCTCPrefixBeamSearch(self, beamSize, vocPruneSize=...) -> retval:
        """
        * @brief Set the decoding method options for `"CTC-prefix-beam-search"` decode usage
        * @param[in] beamSize Beam size for search
        * @param[in] vocPruneSize Parameter to optimize big vocabulary search, * only take top @p vocPruneSize tokens in each search step, @p vocPruneSize <= 0 stands for disable this prune.
        """

    def setDecodeType(self, decodeType) -> retval:
        """
        * @brief Set the decoding method of translating the network output into string
        * @param[in] decodeType The decoding method of translating the network output into string, currently supported type: *    - `"CTC-greedy"` greedy decoding for the output of CTC-based methods *    - `"CTC-prefix-beam-search"` Prefix beam search decoding for the output of CTC-based methods
        """

    def setVocabulary(self, vocabulary) -> retval:
        """
        * @brief Set the vocabulary for recognition.
        * @param[in] vocabulary the associated vocabulary of the network.
        """

def NMSBoxes(bboxes, scores, score_threshold, nms_threshold, eta=..., top_k=...) -> indices:
    """
    @brief Performs non maximum suppression given boxes and corresponding scores.

         * @param bboxes a set of bounding boxes to apply NMS.
         * @param scores a set of corresponding confidences.
         * @param score_threshold a threshold used to filter boxes by score.
         * @param nms_threshold a threshold used in non maximum suppression.
         * @param indices the kept indices of bboxes after NMS.
         * @param eta a coefficient in adaptive threshold formula: \f$nms\_threshold_{i+1}=eta\cdot nms\_threshold_i\f$.
         * @param top_k if `>0`, keep at most @p top_k picked indices.
    """

def NMSBoxesBatched(bboxes, scores, class_ids, score_threshold, nms_threshold, eta=..., top_k=...) -> indices:
    """
    @brief Performs batched non maximum suppression on given boxes and corresponding scores across different classes.

         * @param bboxes a set of bounding boxes to apply NMS.
         * @param scores a set of corresponding confidences.
         * @param class_ids a set of corresponding class ids. Ids are integer and usually start from 0.
         * @param score_threshold a threshold used to filter boxes by score.
         * @param nms_threshold a threshold used in non maximum suppression.
         * @param indices the kept indices of bboxes after NMS.
         * @param eta a coefficient in adaptive threshold formula: \f$nms\_threshold_{i+1}=eta\cdot nms\_threshold_i\f$.
         * @param top_k if `>0`, keep at most @p top_k picked indices.
    """

def NMSBoxesRotated(bboxes, scores, score_threshold, nms_threshold, eta=..., top_k=...) -> indices:
    """
    .
    """

@overload
def Net_readFromModelOptimizer(xml, bin) -> retval:
    """
    @brief Create a network from Intel's Model Optimizer intermediate representation (IR).
             *  @param[in] xml XML configuration file with network's topology.
             *  @param[in] bin Binary file with trained weights.
             *  Networks imported from Intel's Model Optimizer are launched in Intel's Inference Engine
             *  backend.
    """

@overload
def Net_readFromModelOptimizer(xml, bin) -> retval:
    """
    @brief Create a network from Intel's Model Optimizer in-memory buffers with intermediate representation (IR).
             *  @param[in] bufferModelConfig buffer with model's configuration.
             *  @param[in] bufferWeights buffer with model's trained weights.
             *  @returns Net object.
    """

def blobFromImage(image, scalefactor=..., size=..., mean=..., swapRB=..., crop=..., ddepth=...) -> retval:
    """
    @brief Creates 4-dimensional blob from image. Optionally resizes and crops @p image from center,
         *  subtract @p mean values, scales values by @p scalefactor, swap Blue and Red channels.
         *  @param image input image (with 1-, 3- or 4-channels).
         *  @param size spatial size for output image
         *  @param mean scalar with mean values which are subtracted from channels. Values are intended
         *  to be in (mean-R, mean-G, mean-B) order if @p image has BGR ordering and @p swapRB is true.
         *  @param scalefactor multiplier for @p image values.
         *  @param swapRB flag which indicates that swap first and last channels
         *  in 3-channel image is necessary.
         *  @param crop flag which indicates whether image will be cropped after resize or not
         *  @param ddepth Depth of output blob. Choose CV_32F or CV_8U.
         *  @details if @p crop is true, input image is resized so one side after resize is equal to corresponding
         *  dimension in @p size and another one is equal or larger. Then, crop from the center is performed.
         *  If @p crop is false, direct resize without cropping and preserving aspect ratio is performed.
         *  @returns 4-dimensional Mat with NCHW dimensions order.
    """

def blobFromImages(images, scalefactor=..., size=..., mean=..., swapRB=..., crop=..., ddepth=...) -> retval:
    """
    @brief Creates 4-dimensional blob from series of images. Optionally resizes and
         *  crops @p images from center, subtract @p mean values, scales values by @p scalefactor,
         *  swap Blue and Red channels.
         *  @param images input images (all with 1-, 3- or 4-channels).
         *  @param size spatial size for output image
         *  @param mean scalar with mean values which are subtracted from channels. Values are intended
         *  to be in (mean-R, mean-G, mean-B) order if @p image has BGR ordering and @p swapRB is true.
         *  @param scalefactor multiplier for @p images values.
         *  @param swapRB flag which indicates that swap first and last channels
         *  in 3-channel image is necessary.
         *  @param crop flag which indicates whether image will be cropped after resize or not
         *  @param ddepth Depth of output blob. Choose CV_32F or CV_8U.
         *  @details if @p crop is true, input image is resized so one side after resize is equal to corresponding
         *  dimension in @p size and another one is equal or larger. Then, crop from the center is performed.
         *  If @p crop is false, direct resize without cropping and preserving aspect ratio is performed.
         *  @returns 4-dimensional Mat with NCHW dimensions order.
    """

def getAvailableTargets(be) -> retval:
    """
    .
    """

def imagesFromBlob(blob_, images_=...) -> images_:
    """
    @brief Parse a 4D blob and output the images it contains as 2D arrays through a simpler data structure
         *  (std::vector<cv::Mat>).
         *  @param[in] blob_ 4 dimensional array (images, channels, height, width) in floating point precision (CV_32F) from
         *  which you would like to extract the images.
         *  @param[out] images_ array of 2D Mat containing the images extracted from the blob in floating point precision
         *  (CV_32F). They are non normalized neither mean added. The number of returned images equals the first dimension
         *  of the blob (batch size). Every image has a number of channels equals to the second dimension of the blob (depth).
    """

@overload
def readNet(model, config=..., framework=...) -> retval:
    """
    * @brief Read deep learning network represented in one of the supported formats.
          * @param[in] model Binary file contains trained weights. The following file
          *                  extensions are expected for models from different frameworks:
          *                  * `*.caffemodel` (Caffe, http://caffe.berkeleyvision.org/)
          *                  * `*.pb` (TensorFlow, https://www.tensorflow.org/)
          *                  * `*.t7` | `*.net` (Torch, http://torch.ch/)
          *                  * `*.weights` (Darknet, https://pjreddie.com/darknet/)
          *                  * `*.bin` (DLDT, https://software.intel.com/openvino-toolkit)
          *                  * `*.onnx` (ONNX, https://onnx.ai/)
          * @param[in] config Text file contains network configuration. It could be a
          *                   file with the following extensions:
          *                  * `*.prototxt` (Caffe, http://caffe.berkeleyvision.org/)
          *                  * `*.pbtxt` (TensorFlow, https://www.tensorflow.org/)
          *                  * `*.cfg` (Darknet, https://pjreddie.com/darknet/)
          *                  * `*.xml` (DLDT, https://software.intel.com/openvino-toolkit)
          * @param[in] framework Explicit framework name tag to determine a format.
          * @returns Net object.
          *
          * This function automatically detects an origin framework of trained model
          * and calls an appropriate function such @ref readNetFromCaffe, @ref readNetFromTensorflow,
          * @ref readNetFromTorch or @ref readNetFromDarknet. An order of @p model and @p config
          * arguments does not matter.
    """

@overload
def readNet(model, config=..., framework=...) -> retval:
    """
    * @brief Read deep learning network represented in one of the supported formats.
          * @details This is an overloaded member function, provided for convenience.
          *          It differs from the above function only in what argument(s) it accepts.
          * @param[in] framework    Name of origin framework.
          * @param[in] bufferModel  A buffer with a content of binary file with weights
          * @param[in] bufferConfig A buffer with a content of text file contains network configuration.
          * @returns Net object.
    """

@overload
def readNetFromCaffe(prototxt, caffeModel=...) -> retval:
    """
    @brief Reads a network model stored in <a href="http://caffe.berkeleyvision.org">Caffe</a> framework's format.
          * @param prototxt   path to the .prototxt file with text description of the network architecture.
          * @param caffeModel path to the .caffemodel file with learned network.
          * @returns Net object.
    """

@overload
def readNetFromCaffe(prototxt, caffeModel=...) -> retval:
    """
    @brief Reads a network model stored in Caffe model in memory.
          * @param bufferProto buffer containing the content of the .prototxt file
          * @param bufferModel buffer containing the content of the .caffemodel file
          * @returns Net object.
    """

@overload
def readNetFromDarknet(cfgFile, darknetModel=...) -> retval:
    """
    @brief Reads a network model stored in <a href="https://pjreddie.com/darknet/">Darknet</a> model files.
        *  @param cfgFile      path to the .cfg file with text description of the network architecture.
        *  @param darknetModel path to the .weights file with learned network.
        *  @returns Network object that ready to do forward, throw an exception in failure cases.
        *  @returns Net object.
    """

@overload
def readNetFromDarknet(cfgFile, darknetModel=...) -> retval:
    """
    @brief Reads a network model stored in <a href="https://pjreddie.com/darknet/">Darknet</a> model files.
         *  @param bufferCfg   A buffer contains a content of .cfg file with text description of the network architecture.
         *  @param bufferModel A buffer contains a content of .weights file with learned network.
         *  @returns Net object.
    """

@overload
def readNetFromModelOptimizer(xml, bin) -> retval:
    """
    @brief Load a network from Intel's Model Optimizer intermediate representation.
         *  @param[in] xml XML configuration file with network's topology.
         *  @param[in] bin Binary file with trained weights.
         *  @returns Net object.
         *  Networks imported from Intel's Model Optimizer are launched in Intel's Inference Engine
         *  backend.
    """

@overload
def readNetFromModelOptimizer(xml, bin) -> retval:
    """
    @brief Load a network from Intel's Model Optimizer intermediate representation.
         *  @param[in] bufferModelConfig Buffer contains XML configuration with network's topology.
         *  @param[in] bufferWeights Buffer contains binary data with trained weights.
         *  @returns Net object.
         *  Networks imported from Intel's Model Optimizer are launched in Intel's Inference Engine
         *  backend.
    """

@overload
def readNetFromONNX(onnxFile) -> retval:
    """
    @brief Reads a network model <a href="https://onnx.ai/">ONNX</a>.
         *  @param onnxFile path to the .onnx file with text description of the network architecture.
         *  @returns Network object that ready to do forward, throw an exception in failure cases.
    """

@overload
def readNetFromONNX(onnxFile) -> retval:
    """
    @brief Reads a network model from <a href="https://onnx.ai/">ONNX</a>
         *         in-memory buffer.
         *  @param buffer in-memory buffer that stores the ONNX model bytes.
         *  @returns Network object that ready to do forward, throw an exception
         *        in failure cases.
    """

@overload
def readNetFromTensorflow(model, config=...) -> retval:
    """
    @brief Reads a network model stored in <a href="https://www.tensorflow.org/">TensorFlow</a> framework's format.
          * @param model  path to the .pb file with binary protobuf description of the network architecture
          * @param config path to the .pbtxt file that contains text graph definition in protobuf format.
          *               Resulting Net object is built by text graph using weights from a binary one that
          *               let us make it more flexible.
          * @returns Net object.
    """

@overload
def readNetFromTensorflow(model, config=...) -> retval:
    """
    @brief Reads a network model stored in <a href="https://www.tensorflow.org/">TensorFlow</a> framework's format.
          * @param bufferModel buffer containing the content of the pb file
          * @param bufferConfig buffer containing the content of the pbtxt file
          * @returns Net object.
    """

def readNetFromTorch(model, isBinary=..., evaluate=...) -> retval:
    """
    *  @brief Reads a network model stored in <a href="http://torch.ch">Torch7</a> framework's format.
         *  @param model    path to the file, dumped from Torch by using torch.save() function.
         *  @param isBinary specifies whether the network was serialized in ascii mode or binary.
         *  @param evaluate specifies testing phase of network. If true, it's similar to evaluate() method in Torch.
         *  @returns Net object.
         *
         *  @note Ascii mode of Torch serializer is more preferable, because binary mode extensively use `long` type of C language,
         *  which has various bit-length on different systems.
         *
         * The loading file must contain serialized <a href="https://github.com/torch/nn/blob/master/doc/module.md">nn.Module</a> object
         * with importing network. Try to eliminate a custom objects from serialazing data to avoid importing errors.
         *
         * List of supported layers (i.e. object instances derived from Torch nn.Module class):
         * - nn.Sequential
         * - nn.Parallel
         * - nn.Concat
         * - nn.Linear
         * - nn.SpatialConvolution
         * - nn.SpatialMaxPooling, nn.SpatialAveragePooling
         * - nn.ReLU, nn.TanH, nn.Sigmoid
         * - nn.Reshape
         * - nn.SoftMax, nn.LogSoftMax
         *
         * Also some equivalents of these classes from cunn, cudnn, and fbcunn may be successfully imported.
    """

def readTensorFromONNX(path) -> retval:
    """
    @brief Creates blob from .pb file.
         *  @param path to the .pb file with input tensor.
         *  @returns Mat.
    """

def readTorchBlob(filename, isBinary=...) -> retval:
    """
    @brief Loads blob which was serialized as torch.Tensor object of Torch7 framework.
         *  @warning This function has the same limitations as readNetFromTorch().
    """

def shrinkCaffeModel(src, dst, layersTypes=...) -> None:
    """
    @brief Convert all weights of Caffe network to half precision floating point.
         * @param src Path to origin model from Caffe framework contains single
         *            precision floating point weights (usually has `.caffemodel` extension).
         * @param dst Path to destination model with updated weights.
         * @param layersTypes Set of layers types which parameters will be converted.
         *                    By default, converts only Convolutional and Fully-Connected layers'
         *                    weights.
         *
         * @note Shrinked model has no origin float32 weights so it can't be used
         *       in origin Caffe framework anymore. However the structure of data
         *       is taken from NVidia's Caffe fork: https://github.com/NVIDIA/caffe.
         *       So the resulting model may be used there.
    """

def softNMSBoxes(bboxes, scores, score_threshold, nms_threshold, top_k=..., sigma=..., method=...) -> tuple[updated_scores, indices]:
    """
    @brief Performs soft non maximum suppression given boxes and corresponding scores.
         * Reference: https://arxiv.org/abs/1704.04503
         * @param bboxes a set of bounding boxes to apply Soft NMS.
         * @param scores a set of corresponding confidences.
         * @param updated_scores a set of corresponding updated confidences.
         * @param score_threshold a threshold used to filter boxes by score.
         * @param nms_threshold a threshold used in non maximum suppression.
         * @param indices the kept indices of bboxes after NMS.
         * @param top_k keep at most @p top_k picked indices.
         * @param sigma parameter of Gaussian weighting.
         * @param method Gaussian or linear.
         * @see SoftNMSMethod
    """

def writeTextGraph(model, output) -> None:
    """
    @brief Create a text representation for a binary network stored in protocol buffer format.
         *  @param[in] model  A path to binary network.
         *  @param[in] output A path to output text file to be created.
         *
         *  @note To reduce output file size, trained weights are not included.
    """

DNN_BACKEND_CANN: Final[int]
DNN_BACKEND_CUDA: Final[int]
DNN_BACKEND_DEFAULT: Final[int]
DNN_BACKEND_HALIDE: Final[int]
DNN_BACKEND_INFERENCE_ENGINE: Final[int]
DNN_BACKEND_OPENCV: Final[int]
DNN_BACKEND_TIMVX: Final[int]
DNN_BACKEND_VKCOM: Final[int]
DNN_BACKEND_WEBNN: Final[int]
DNN_TARGET_CPU: Final[int]
DNN_TARGET_CUDA: Final[int]
DNN_TARGET_CUDA_FP16: Final[int]
DNN_TARGET_FPGA: Final[int]
DNN_TARGET_HDDL: Final[int]
DNN_TARGET_MYRIAD: Final[int]
DNN_TARGET_NPU: Final[int]
DNN_TARGET_OPENCL: Final[int]
DNN_TARGET_OPENCL_FP16: Final[int]
DNN_TARGET_VULKAN: Final[int]
SOFT_NMSMETHOD_SOFTNMS_GAUSSIAN: Final[int]
SOFT_NMSMETHOD_SOFTNMS_LINEAR: Final[int]
SoftNMSMethod_SOFTNMS_GAUSSIAN: Final[int]
SoftNMSMethod_SOFTNMS_LINEAR: Final[int]



from typing import Final

BAD_ALIGN: Final[int]
BAD_ALPHA_CHANNEL: Final[int]
BAD_CALL_BACK: Final[int]
BAD_COI: Final[int]
BAD_DATA_PTR: Final[int]
BAD_DEPTH: Final[int]
BAD_IMAGE_SIZE: Final[int]
BAD_MODEL_OR_CH_SEQ: Final[int]
BAD_NUM_CHANNEL1U: Final[int]
BAD_NUM_CHANNELS: Final[int]
BAD_OFFSET: Final[int]
BAD_ORDER: Final[int]
BAD_ORIGIN: Final[int]
BAD_ROISIZE: Final[int]
BAD_STEP: Final[int]
BAD_TILE_SIZE: Final[int]
BadAlign: Final[int]
BadAlphaChannel: Final[int]
BadCOI: Final[int]
BadCallBack: Final[int]
BadDataPtr: Final[int]
BadDepth: Final[int]
BadImageSize: Final[int]
BadModelOrChSeq: Final[int]
BadNumChannel1U: Final[int]
BadNumChannels: Final[int]
BadOffset: Final[int]
BadOrder: Final[int]
BadOrigin: Final[int]
BadROISize: Final[int]
BadStep: Final[int]
BadTileSize: Final[int]
GPU_API_CALL_ERROR: Final[int]
GPU_NOT_SUPPORTED: Final[int]
GpuApiCallError: Final[int]
GpuNotSupported: Final[int]
HEADER_IS_NULL: Final[int]
HeaderIsNull: Final[int]
MASK_IS_TILED: Final[int]
MaskIsTiled: Final[int]
OPEN_CLAPI_CALL_ERROR: Final[int]
OPEN_CLDOUBLE_NOT_SUPPORTED: Final[int]
OPEN_CLINIT_ERROR: Final[int]
OPEN_CLNO_AMDBLAS_FFT: Final[int]
OPEN_GL_API_CALL_ERROR: Final[int]
OPEN_GL_NOT_SUPPORTED: Final[int]
OpenCLApiCallError: Final[int]
OpenCLDoubleNotSupported: Final[int]
OpenCLInitError: Final[int]
OpenCLNoAMDBlasFft: Final[int]
OpenGlApiCallError: Final[int]
OpenGlNotSupported: Final[int]
STS_ASSERT: Final[int]
STS_AUTO_TRACE: Final[int]
STS_BACK_TRACE: Final[int]
STS_BAD_ARG: Final[int]
STS_BAD_FLAG: Final[int]
STS_BAD_FUNC: Final[int]
STS_BAD_MASK: Final[int]
STS_BAD_MEM_BLOCK: Final[int]
STS_BAD_POINT: Final[int]
STS_BAD_SIZE: Final[int]
STS_DIV_BY_ZERO: Final[int]
STS_ERROR: Final[int]
STS_FILTER_OFFSET_ERR: Final[int]
STS_FILTER_STRUCT_CONTENT_ERR: Final[int]
STS_INPLACE_NOT_SUPPORTED: Final[int]
STS_INTERNAL: Final[int]
STS_KERNEL_STRUCT_CONTENT_ERR: Final[int]
STS_NOT_IMPLEMENTED: Final[int]
STS_NO_CONV: Final[int]
STS_NO_MEM: Final[int]
STS_NULL_PTR: Final[int]
STS_OBJECT_NOT_FOUND: Final[int]
STS_OK: Final[int]
STS_OUT_OF_RANGE: Final[int]
STS_PARSE_ERROR: Final[int]
STS_UNMATCHED_FORMATS: Final[int]
STS_UNMATCHED_SIZES: Final[int]
STS_UNSUPPORTED_FORMAT: Final[int]
STS_VEC_LENGTH_ERR: Final[int]
StsAssert: Final[int]
StsAutoTrace: Final[int]
StsBackTrace: Final[int]
StsBadArg: Final[int]
StsBadFlag: Final[int]
StsBadFunc: Final[int]
StsBadMask: Final[int]
StsBadMemBlock: Final[int]
StsBadPoint: Final[int]
StsBadSize: Final[int]
StsDivByZero: Final[int]
StsError: Final[int]
StsFilterOffsetErr: Final[int]
StsFilterStructContentErr: Final[int]
StsInplaceNotSupported: Final[int]
StsInternal: Final[int]
StsKernelStructContentErr: Final[int]
StsNoConv: Final[int]
StsNoMem: Final[int]
StsNotImplemented: Final[int]
StsNullPtr: Final[int]
StsObjectNotFound: Final[int]
StsOk: Final[int]
StsOutOfRange: Final[int]
StsParseError: Final[int]
StsUnmatchedFormats: Final[int]
StsUnmatchedSizes: Final[int]
StsUnsupportedFormat: Final[int]
StsVecLengthErr: Final[int]



import builtins
from typing import Any, Final, TypeAlias

from .. import functions as cv2

img: TypeAlias = Any
retval: TypeAlias = Any

class CChecker:
    def getBox(self) -> retval:
        """"""

    def getCenter(self) -> retval:
        """"""

    def getChartsRGB(self) -> retval:
        """"""

    def getChartsYCbCr(self) -> retval:
        """"""

    def getCost(self) -> retval:
        """"""

    def getTarget(self) -> retval:
        """"""

    def setBox(self, _box) -> None:
        """"""

    def setCenter(self, _center) -> None:
        """"""

    def setChartsRGB(self, _chartsRGB) -> None:
        """"""

    def setChartsYCbCr(self, _chartsYCbCr) -> None:
        """"""

    def setCost(self, _cost) -> None:
        """"""

    def setTarget(self, _target) -> None:
        """"""

    def create(self) -> retval:
        """
        \brief Create a new CChecker object.
        * \return A pointer to the implementation of the CChecker
        """

class CCheckerDetector(cv2.Algorithm):
    def getBestColorChecker(self) -> retval:
        """
        \brief Get the best color checker. By the best it means the one
        *         detected with the highest confidence.
        * \return checker A single colorchecker, if atleast one colorchecker
        *                 was detected, 'nullptr' otherwise.
        """

    def getListColorChecker(self) -> retval:
        """
        \brief Get the list of all detected colorcheckers
        * \return checkers vector of colorcheckers
        """

    def process(self, image, chartType, nc=..., useNet=..., params=...) -> retval:
        """
        \brief Find the ColorCharts in the given image.
        *
        * Differs from the above one only in the arguments.
        *
        * This version searches for the chart in the full image.
        *
        * The found charts are not returned but instead stored in the
        * detector, these can be accessed later on using getBestColorChecker()
        * and getListColorChecker()
        * \param image image in color space BGR
        * \param chartType type of the chart to detect
        * \param nc number of charts in the image, if you don't know the exact
        *           then keeping this number high helps.
        * \param useNet if it is true the network provided using the setNet()
        *               is used for preliminary search for regions where chart
        *               could be present, inside the regionsOfInterest provied.
        * \param params parameters of the detection system. More information
        *               about them can be found in the struct DetectorParameters.
        * \return true if atleast one chart is detected otherwise false
        """

    def processWithROI(self, image, chartType, regionsOfInterest, nc=..., useNet=..., params=...) -> retval:
        """
        \brief Find the ColorCharts in the given image.
        *
        * The found charts are not returned but instead stored in the
        * detector, these can be accessed later on using getBestColorChecker()
        * and getListColorChecker()
        * \param image image in color space BGR
        * \param chartType type of the chart to detect
        * \param regionsOfInterest regions of image to look for the chart, if
        *                          it is empty, charts are looked for in the
        *                          entire image
        * \param nc number of charts in the image, if you don't know the exact
        *           then keeping this number high helps.
        * \param useNet if it is true the network provided using the setNet()
        *               is used for preliminary search for regions where chart
        *               could be present, inside the regionsOfInterest provied.
        * \param params parameters of the detection system. More information
        *               about them can be found in the struct DetectorParameters.
        * \return true if atleast one chart is detected otherwise false
        """

    def setNet(self, net) -> retval:
        """
        \brief Set the net which will be used to find the approximate
        *         bounding boxes for the color charts.
        *
        * It is not necessary to use this, but this usually results in
        * better detection rate.
        *
        * \param net the neural network, if the network in empty, then
        *            the function will return false.
        * \return true if it was able to set the detector's network,
        *         false otherwise.
        """

    def create(self) -> retval:
        """
        \brief Returns the implementation of the CCheckerDetector.
        *
        """

class CCheckerDraw:
    def draw(self, img) -> img:
        """
        \brief Draws the checker to the given image.
        * \param img image in color space BGR
        * \return void
        """

    def create(self, pChecker, color=..., thickness=...) -> retval:
        """
        \brief Create a new CCheckerDraw object.
        * \param pChecker The checker which will be drawn by this object.
        * \param color The color by with which the squares of the checker
        *              will be drawn
        * \param thickness The thickness with which the sqaures will be
        *                  drawn
        * \return A pointer to the implementation of the CCheckerDraw
        """

class DetectorParameters:
    def create(self) -> retval:
        """"""

def CCheckerDetector_create() -> retval:
    """
    \brief Returns the implementation of the CCheckerDetector.
        *
    """

def CCheckerDraw_create(pChecker, color=..., thickness=...) -> retval:
    """
    \brief Create a new CCheckerDraw object.
        * \param pChecker The checker which will be drawn by this object.
        * \param color The color by with which the squares of the checker
        *              will be drawn
        * \param thickness The thickness with which the sqaures will be
        *                  drawn
        * \return A pointer to the implementation of the CCheckerDraw
    """

def CChecker_create() -> retval:
    """
    \brief Create a new CChecker object.
        * \return A pointer to the implementation of the CChecker
    """

def DetectorParameters_create() -> retval:
    """
    .
    """

MCC24: Final[int]
SG140: int
VINYL18: Final[int]



from typing import Any, Final, overload, TypeAlias

rvecs: TypeAlias = Any
K2: TypeAlias = Any
xi2: TypeAlias = Any
xi1: TypeAlias = Any
disparity: TypeAlias = Any
R1: TypeAlias = Any
map1: TypeAlias = Any
tvecsL: TypeAlias = Any
R2: TypeAlias = Any
tvec: TypeAlias = Any
rvecsL: TypeAlias = Any
D: TypeAlias = Any
image1Rec: TypeAlias = Any
idx: TypeAlias = Any
K1: TypeAlias = Any
rvec: TypeAlias = Any
imagePoints1: TypeAlias = Any
map2: TypeAlias = Any
imagePoints2: TypeAlias = Any
D1: TypeAlias = Any
xi: TypeAlias = Any
jacobian: TypeAlias = Any
D2: TypeAlias = Any
K: TypeAlias = Any
imagePoints: TypeAlias = Any
image2Rec: TypeAlias = Any
pointCloud: TypeAlias = Any
tvecs: TypeAlias = Any
objectPoints: TypeAlias = Any
undistorted: TypeAlias = Any
retval: TypeAlias = Any

@overload
def calibrate(objectPoints, imagePoints, size, K, xi, D, flags, criteria, rvecs=..., tvecs=..., idx=...) -> tuple[retval, K, xi, D, rvecs, tvecs, idx]:
    """
    @brief Perform omnidirectional camera calibration, the default depth of outputs is CV_64F.

        @param objectPoints Vector of vector of Vec3f object points in world (pattern) coordinate.
    """

@overload
def calibrate(objectPoints, imagePoints, size, K, xi, D, flags, criteria, rvecs=..., tvecs=..., idx=...) -> tuple[retval, K, xi, D, rvecs, tvecs, idx]:
    """
    @param imagePoints Vector of vector of Vec2f corresponding image points of objectPoints. It must be the same
    """

@overload
def calibrate(objectPoints, imagePoints, size, K, xi, D, flags, criteria, rvecs=..., tvecs=..., idx=...) -> tuple[retval, K, xi, D, rvecs, tvecs, idx]:
    """
    @param size Image size of calibration images.
    @param K Output calibrated camera matrix.
    @param xi Output parameter xi for CMei's model
    @param D Output distortion parameters \f$(k_1, k_2, p_1, p_2)\f$
    @param rvecs Output rotations for each calibration images
    @param tvecs Output translation for each calibration images
    @param flags The flags that control calibrate
    @param criteria Termination criteria for optimization
    @param idx Indices of images that pass initialization, which are really used in calibration. So the size of rvecs is the
    """

@overload
def calibrate(objectPoints, imagePoints, size, K, xi, D, flags, criteria, rvecs=..., tvecs=..., idx=...) -> tuple[retval, K, xi, D, rvecs, tvecs, idx]:
    """ """

@overload
def initUndistortRectifyMap(K, D, xi, R, P, size, m1type, flags, map1=..., map2=...) -> tuple[map1, map2]:
    """
    @brief Computes undistortion and rectification maps for omnidirectional camera image transform by a rotation R.
    """

@overload
def initUndistortRectifyMap(K, D, xi, R, P, size, m1type, flags, map1=..., map2=...) -> tuple[map1, map2]:
    """ """

@overload
def initUndistortRectifyMap(K, D, xi, R, P, size, m1type, flags, map1=..., map2=...) -> tuple[map1, map2]:
    """

    @param K Camera matrix \f$K = \vecthreethree{f_x}{s}{c_x}{0}{f_y}{c_y}{0}{0}{_1}\f$, with depth CV_32F or CV_64F
    @param D Input vector of distortion coefficients \f$(k_1, k_2, p_1, p_2)\f$, with depth CV_32F or CV_64F
    @param xi The parameter xi for CMei's model
    @param R Rotation transform between the original and object space : 3x3 1-channel, or vector: 3x1/1x3, with depth CV_32F or CV_64F
    @param P New camera matrix (3x3) or new projection matrix (3x4)
    @param size Undistorted image size.
    @param m1type Type of the first output map that can be CV_32FC1 or CV_16SC2 . See convertMaps()
    """

@overload
def initUndistortRectifyMap(K, D, xi, R, P, size, m1type, flags, map1=..., map2=...) -> tuple[map1, map2]:
    """
    @param map1 The first output map.
    @param map2 The second output map.
    @param flags Flags indicates the rectification type,  RECTIFY_PERSPECTIVE, RECTIFY_CYLINDRICAL, RECTIFY_LONGLATI and RECTIFY_STEREOGRAPHIC
    """

@overload
def initUndistortRectifyMap(K, D, xi, R, P, size, m1type, flags, map1=..., map2=...) -> tuple[map1, map2]:
    """ """

@overload
def projectPoints(objectPoints, rvec, tvec, K, xi, D, imagePoints=..., jacobian=...) -> tuple[imagePoints, jacobian]:
    """
    @brief Projects points for omnidirectional camera using CMei's model

        @param objectPoints Object points in world coordinate, vector of vector of Vec3f or Mat of
        1xN/Nx1 3-channel of type CV_32F and N is the number of points. 64F is also acceptable.
        @param imagePoints Output array of image points, vector of vector of Vec2f or
        1xN/Nx1 2-channel of type CV_32F. 64F is also acceptable.
        @param rvec vector of rotation between world coordinate and camera coordinate, i.e., om
        @param tvec vector of translation between pattern coordinate and camera coordinate
        @param K Camera matrix \f$K = \vecthreethree{f_x}{s}{c_x}{0}{f_y}{c_y}{0}{0}{_1}\f$.
        @param D Input vector of distortion coefficients \f$(k_1, k_2, p_1, p_2)\f$.
        @param xi The parameter xi for CMei's model
        @param jacobian Optional output 2Nx16 of type CV_64F jacobian matrix, contains the derivatives of
    """

@overload
def projectPoints(objectPoints, rvec, tvec, K, xi, D, imagePoints=..., jacobian=...) -> tuple[imagePoints, jacobian]:
    """ """

@overload
def projectPoints(objectPoints, rvec, tvec, K, xi, D, imagePoints=..., jacobian=...) -> tuple[imagePoints, jacobian]:
    """ """

@overload
def projectPoints(objectPoints, rvec, tvec, K, xi, D, imagePoints=..., jacobian=...) -> tuple[imagePoints, jacobian]:
    """ """

@overload
def projectPoints(objectPoints, rvec, tvec, K, xi, D, imagePoints=..., jacobian=...) -> tuple[imagePoints, jacobian]:
    """ """

@overload
def projectPoints(objectPoints, rvec, tvec, K, xi, D, imagePoints=..., jacobian=...) -> tuple[imagePoints, jacobian]:
    """ """

@overload
def stereoCalibrate(objectPoints, imagePoints1, imagePoints2, imageSize1, imageSize2, K1, xi1, D1, K2, xi2, D2, flags, criteria, rvec=..., tvec=..., rvecsL=..., tvecsL=..., idx=...) -> tuple[retval, objectPoints, imagePoints1, imagePoints2, K1, xi1, D1, K2, xi2, D2, rvec, tvec, rvecsL, tvecsL, idx]:
    """
    @brief Stereo calibration for omnidirectional camera model. It computes the intrinsic parameters for two
    """

@overload
def stereoCalibrate(objectPoints, imagePoints1, imagePoints2, imageSize1, imageSize2, K1, xi1, D1, K2, xi2, D2, flags, criteria, rvec=..., tvec=..., rvecsL=..., tvecsL=..., idx=...) -> tuple[retval, objectPoints, imagePoints1, imagePoints2, K1, xi1, D1, K2, xi2, D2, rvec, tvec, rvecsL, tvecsL, idx]:
    """

    @param objectPoints Object points in world (pattern) coordinate. Its type is vector<vector<Vec3f> >.
    """

@overload
def stereoCalibrate(objectPoints, imagePoints1, imagePoints2, imageSize1, imageSize2, K1, xi1, D1, K2, xi2, D2, flags, criteria, rvec=..., tvec=..., rvecsL=..., tvecsL=..., idx=...) -> tuple[retval, objectPoints, imagePoints1, imagePoints2, K1, xi1, D1, K2, xi2, D2, rvec, tvec, rvecsL, tvecsL, idx]:
    """
    @param imagePoints1 The corresponding image points of the first camera, with type vector<vector<Vec2f> >.
    """

@overload
def stereoCalibrate(objectPoints, imagePoints1, imagePoints2, imageSize1, imageSize2, K1, xi1, D1, K2, xi2, D2, flags, criteria, rvec=..., tvec=..., rvecsL=..., tvecsL=..., idx=...) -> tuple[retval, objectPoints, imagePoints1, imagePoints2, K1, xi1, D1, K2, xi2, D2, rvec, tvec, rvecsL, tvecsL, idx]:
    """
    @param imagePoints2 The corresponding image points of the second camera, with type vector<vector<Vec2f> >.
    """

@overload
def stereoCalibrate(objectPoints, imagePoints1, imagePoints2, imageSize1, imageSize2, K1, xi1, D1, K2, xi2, D2, flags, criteria, rvec=..., tvec=..., rvecsL=..., tvecsL=..., idx=...) -> tuple[retval, objectPoints, imagePoints1, imagePoints2, K1, xi1, D1, K2, xi2, D2, rvec, tvec, rvecsL, tvecsL, idx]:
    """
    @param imageSize1 Image size of calibration images of the first camera.
    @param imageSize2 Image size of calibration images of the second camera.
    @param K1 Output camera matrix for the first camera.
    @param xi1 Output parameter xi of Mei's model for the first camera
    @param D1 Output distortion parameters \f$(k_1, k_2, p_1, p_2)\f$ for the first camera
    @param K2 Output camera matrix for the first camera.
    @param xi2 Output parameter xi of CMei's model for the second camera
    @param D2 Output distortion parameters \f$(k_1, k_2, p_1, p_2)\f$ for the second camera
    @param rvec Output rotation between the first and second camera
    @param tvec Output translation between the first and second camera
    @param rvecsL Output rotation for each image of the first camera
    @param tvecsL Output translation for each image of the first camera
    @param flags The flags that control stereoCalibrate
    @param criteria Termination criteria for optimization
    @param idx Indices of image pairs that pass initialization, which are really used in calibration. So the size of rvecs is the
    """

@overload
def stereoCalibrate(objectPoints, imagePoints1, imagePoints2, imageSize1, imageSize2, K1, xi1, D1, K2, xi2, D2, flags, criteria, rvec=..., tvec=..., rvecsL=..., tvecsL=..., idx=...) -> tuple[retval, objectPoints, imagePoints1, imagePoints2, K1, xi1, D1, K2, xi2, D2, rvec, tvec, rvecsL, tvecsL, idx]:
    """
    @
    """

def stereoReconstruct(image1, image2, K1, D1, xi1, K2, D2, xi2, R, T, flag, numDisparities, SADWindowSize, disparity=..., image1Rec=..., image2Rec=..., newSize=..., Knew=..., pointCloud=..., pointType=...) -> tuple[disparity, image1Rec, image2Rec, pointCloud]:
    """
    @brief Stereo 3D reconstruction from a pair of images

        @param image1 The first input image
        @param image2 The second input image
        @param K1 Input camera matrix of the first camera
        @param D1 Input distortion parameters \f$(k_1, k_2, p_1, p_2)\f$ for the first camera
        @param xi1 Input parameter xi for the first camera for CMei's model
        @param K2 Input camera matrix of the second camera
        @param D2 Input distortion parameters \f$(k_1, k_2, p_1, p_2)\f$ for the second camera
        @param xi2 Input parameter xi for the second camera for CMei's model
        @param R Rotation between the first and second camera
        @param T Translation between the first and second camera
        @param flag Flag of rectification type, RECTIFY_PERSPECTIVE or RECTIFY_LONGLATI
        @param numDisparities The parameter 'numDisparities' in StereoSGBM, see StereoSGBM for details.
        @param SADWindowSize The parameter 'SADWindowSize' in StereoSGBM, see StereoSGBM for details.
        @param disparity Disparity map generated by stereo matching
        @param image1Rec Rectified image of the first image
        @param image2Rec rectified image of the second image
        @param newSize Image size of rectified image, see omnidir::undistortImage
        @param Knew New camera matrix of rectified image, see omnidir::undistortImage
        @param pointCloud Point cloud of 3D reconstruction, with type CV_64FC3
        @param pointType Point cloud type, it can be XYZRGB or XYZ
    """

def stereoRectify(R, T, R1=..., R2=...) -> tuple[R1, R2]:
    """
    @brief Stereo rectification for omnidirectional camera model. It computes the rectification rotations for two cameras

        @param R Rotation between the first and second camera
        @param T Translation between the first and second camera
        @param R1 Output 3x3 rotation matrix for the first camera
        @param R2 Output 3x3 rotation matrix for the second camera
    """

def undistortImage(distorted, K, D, xi, flags, undistorted=..., Knew=..., new_size=..., R=...) -> undistorted:
    """
    @brief Undistort omnidirectional images to perspective images

        @param distorted The input omnidirectional image.
        @param undistorted The output undistorted image.
        @param K Camera matrix \f$K = \vecthreethree{f_x}{s}{c_x}{0}{f_y}{c_y}{0}{0}{_1}\f$.
        @param D Input vector of distortion coefficients \f$(k_1, k_2, p_1, p_2)\f$.
        @param xi The parameter xi for CMei's model.
        @param flags Flags indicates the rectification type,  RECTIFY_PERSPECTIVE, RECTIFY_CYLINDRICAL, RECTIFY_LONGLATI and RECTIFY_STEREOGRAPHIC
        @param Knew Camera matrix of the distorted image. If it is not assigned, it is just K.
        @param new_size The new image size. By default, it is the size of distorted.
        @param R Rotation matrix between the input and output images. By default, it is identity matrix.
    """

@overload
def undistortPoints(distorted, K, D, xi, R, undistorted=...) -> undistorted:
    """
    @brief Undistort 2D image points for omnidirectional camera using CMei's model

        @param distorted Array of distorted image points, vector of Vec2f
    """

@overload
def undistortPoints(distorted, K, D, xi, R, undistorted=...) -> undistorted:
    """
    @param K Camera matrix \f$K = \vecthreethree{f_x}{s}{c_x}{0}{f_y}{c_y}{0}{0}{_1}\f$.
    @param D Distortion coefficients \f$(k_1, k_2, p_1, p_2)\f$.
    @param xi The parameter xi for CMei's model
    @param R Rotation trainsform between the original and object space : 3x3 1-channel, or vector: 3x1/1x3
    1-channel or 1x1 3-channel
    @param undistorted array of normalized object points, vector of Vec2f/Vec2d or 1xN/Nx1 2-channel Mat with the same
    """

@overload
def undistortPoints(distorted, K, D, xi, R, undistorted=...) -> undistorted:
    """ """

CALIB_FIX_CENTER: Final[int]
CALIB_FIX_GAMMA: Final[int]
CALIB_FIX_K1: Final[int]
CALIB_FIX_K2: Final[int]
CALIB_FIX_P1: Final[int]
CALIB_FIX_P2: Final[int]
CALIB_FIX_SKEW: Final[int]
CALIB_FIX_XI: Final[int]
CALIB_USE_GUESS: Final[int]
RECTIFY_CYLINDRICAL: Final[int]
RECTIFY_LONGLATI: Final[int]
RECTIFY_PERSPECTIVE: Final[int]
RECTIFY_STEREOGRAPHIC: Final[int]
XYZ: Final[int]
XYZRGB: Final[int]



"""Script to set every undefined type as an alias of Any."""
import argparse
import subprocess
from collections import defaultdict
from pathlib import Path


def main() -> None:
    argparse.ArgumentParser(description="Script to set every undefined type as an alias of Any.",
                            formatter_class=argparse.ArgumentDefaultsHelpFormatter)

    print("Running pyright")
    pyright_result = subprocess.run(["pyright", "."], stdout=subprocess.PIPE).stdout.decode().splitlines()

    aliases_to_add: dict[Path, set[str]] = defaultdict(set)
    for line in pyright_result:
        if "is not defined (reportUndefinedVariable)" not in line:
            continue
        file_path = Path(line.split(":", maxsplit=1)[0].lstrip())
        alias_to_add = line.split('"')[1]
        aliases_to_add[file_path].add(alias_to_add)

    print("Adding the following aliases:")
    for path, names in aliases_to_add.items():
        print(f"{path}: {names}")

    for path, names in aliases_to_add.items():
        print(f"Adding aliases to file {path.name}")
        with path.open("r", encoding="utf-8") as stub_file:
            write_line = 0
            while "from" in (line := stub_file.readline().strip()) or "import" in line or line == "":
                write_line += 1
                continue

        write_line = max(1, write_line)
        for name in names:
            subprocess.run(["sed", "-i", f"{write_line}i{name}: TypeAlias = Any\n", path], stdout=subprocess.PIPE)
        subprocess.run(["sed", "-i", f"{write_line}i\n", path], stdout=subprocess.PIPE)

    print("Finished")


if __name__ == "__main__":
    main()



from typing import Any, overload, TypeAlias

from ... import functions as cv2

rects: TypeAlias = Any

dst: TypeAlias = Any
retval: TypeAlias = Any

class GraphSegmentation(cv2.Algorithm):
    def getK(self) -> retval:
        """"""

    def getMinSize(self) -> retval:
        """"""

    def getSigma(self) -> retval:
        """"""

    def processImage(self, src, dst=...) -> dst:
        """
        @brief Segment an image and store output in dst
        @param src The input image. Any number of channel (1 (Eg: Gray), 3 (Eg: RGB), 4 (Eg: RGB-D)) can be provided
        @param dst The output segmentation. It's a CV_32SC1 Mat with the same number of cols and rows as input image, with an unique, sequential, id for each pixel.
        """

    def setK(self, k) -> None:
        """"""

    def setMinSize(self, min_size) -> None:
        """"""

    def setSigma(self, sigma) -> None:
        """"""

class SelectiveSearchSegmentation(cv2.Algorithm):
    def addGraphSegmentation(self, g) -> None:
        """
        @brief Add a new graph segmentation in the list of graph segementations to process.
        @param g The graph segmentation
        """

    def addImage(self, img) -> None:
        """
        @brief Add a new image in the list of images to process.
        @param img The image
        """

    def addStrategy(self, s) -> None:
        """
        @brief Add a new strategy in the list of strategy to process.
        @param s The strategy
        """

    def clearGraphSegmentations(self) -> None:
        """
        @brief Clear the list of graph segmentations to process;
        """

    def clearImages(self) -> None:
        """
        @brief Clear the list of images to process
        """

    def clearStrategies(self) -> None:
        """
        @brief Clear the list of strategy to process;
        """

    def process(self) -> rects:
        """
        @brief Based on all images, graph segmentations and stragies, computes all possible rects and return them
        @param rects The list of rects. The first ones are more relevents than the lasts ones.
        """

    def setBaseImage(self, img) -> None:
        """
        @brief Set a image used by switch* functions to initialize the class
        @param img The image
        """

    def switchToSelectiveSearchFast(self, base_k=..., inc_k=..., sigma=...) -> None:
        """
        @brief Initialize the class with the 'Selective search fast' parameters describled in @cite uijlings2013selective.
        @param base_k The k parameter for the first graph segmentation
        @param inc_k The increment of the k parameter for all graph segmentations
        @param sigma The sigma parameter for the graph segmentation
        """

    def switchToSelectiveSearchQuality(self, base_k=..., inc_k=..., sigma=...) -> None:
        """
        @brief Initialize the class with the 'Selective search fast' parameters describled in @cite uijlings2013selective.
        @param base_k The k parameter for the first graph segmentation
        @param inc_k The increment of the k parameter for all graph segmentations
        @param sigma The sigma parameter for the graph segmentation
        """

    def switchToSingleStrategy(self, k=..., sigma=...) -> None:
        """
        @brief Initialize the class with the 'Single stragegy' parameters describled in @cite uijlings2013selective.
        @param k The k parameter for the graph segmentation
        @param sigma The sigma parameter for the graph segmentation
        """

class SelectiveSearchSegmentationStrategy(cv2.Algorithm):
    def get(self, r1, r2) -> retval:
        """
        @brief Return the score between two regions (between 0 and 1)
        @param r1 The first region
        @param r2 The second region
        """

    def merge(self, r1, r2) -> None:
        """
        @brief Inform the strategy that two regions will be merged
        @param r1 The first region
        @param r2 The second region
        """

    def setImage(self, img, regions, sizes, image_id=...) -> None:
        """
        @brief Set a initial image, with a segmentation.
        @param img The input image. Any number of channel can be provided
        @param regions A segmentation of the image. The parameter must be the same size of img.
        @param sizes The sizes of different regions
        @param image_id If not set to -1, try to cache pre-computations. If the same set og (img, regions, size) is used, the image_id need to be the same.
        """

class SelectiveSearchSegmentationStrategyColor(SelectiveSearchSegmentationStrategy): ...
class SelectiveSearchSegmentationStrategyFill(SelectiveSearchSegmentationStrategy): ...

class SelectiveSearchSegmentationStrategyMultiple(SelectiveSearchSegmentationStrategy):
    def addStrategy(self, g, weight) -> None:
        """
        @brief Add a new sub-strategy
        @param g The strategy
        @param weight The weight of the strategy
        """

    def clearStrategies(self) -> None:
        """
        @brief Remove all sub-strategies
        """

class SelectiveSearchSegmentationStrategySize(SelectiveSearchSegmentationStrategy): ...
class SelectiveSearchSegmentationStrategyTexture(SelectiveSearchSegmentationStrategy): ...

def createGraphSegmentation(sigma=..., k=..., min_size=...) -> retval:
    """
    @brief Creates a graph based segmentor
                            @param sigma The sigma parameter, used to smooth image
                            @param k The k parameter of the algorythm
                            @param min_size The minimum size of segments
    """

def createSelectiveSearchSegmentation() -> retval:
    """
    @brief Create a new SelectiveSearchSegmentation class.
    """

def createSelectiveSearchSegmentationStrategyColor() -> retval:
    """
    @brief Create a new color-based strategy
    """

def createSelectiveSearchSegmentationStrategyFill() -> retval:
    """
    @brief Create a new fill-based strategy
    """

@overload
def createSelectiveSearchSegmentationStrategyMultiple() -> retval:
    """
    @brief Create a new multiple strategy
    """

@overload
def createSelectiveSearchSegmentationStrategyMultiple() -> retval:
    """
    @brief Create a new multiple strategy and set one subtrategy
                            @param s1 The first strategy
    """

@overload
def createSelectiveSearchSegmentationStrategyMultiple() -> retval:
    """
    @brief Create a new multiple strategy and set two subtrategies, with equal weights
                            @param s1 The first strategy
                            @param s2 The second strategy
    """

@overload
def createSelectiveSearchSegmentationStrategyMultiple() -> retval:
    """
    @brief Create a new multiple strategy and set three subtrategies, with equal weights
                            @param s1 The first strategy
                            @param s2 The second strategy
                            @param s3 The third strategy
    """

@overload
def createSelectiveSearchSegmentationStrategyMultiple() -> retval:
    """
    @brief Create a new multiple strategy and set four subtrategies, with equal weights
                            @param s1 The first strategy
                            @param s2 The second strategy
                            @param s3 The third strategy
                            @param s4 The forth strategy
    """

def createSelectiveSearchSegmentationStrategySize() -> retval:
    """
    @brief Create a new size-based strategy
    """

def createSelectiveSearchSegmentationStrategyTexture() -> retval:
    """
    @brief Create a new size-based strategy
    """



import builtins
from typing import Any, overload, TypeAlias

retval: TypeAlias = Any

class Circle: ...
class Image: ...
class Line: ...
class Mosaic: ...
class Poly: ...
class Rect: ...
class Text: ...

@overload
def render(bgr, prims, args=...) -> None:
    """
    @brief The function renders on the input image passed drawing primitivies

    @param bgr input image: 8-bit unsigned 3-channel image @ref CV_8UC3.
    @param prims vector of drawing primitivies
    @param args graph compile time parameters
    """

@overload
def render(bgr, prims, args=...) -> None:
    """
    @brief The function renders on two NV12 planes passed drawing primitivies

    @param y_plane input image: 8-bit unsigned 1-channel image @ref CV_8UC1.
    @param uv_plane input image: 8-bit unsigned 2-channel image @ref CV_8UC2.
    @param prims vector of drawing primitivies
    @param args graph compile time parameters
    """

def render3ch(src, prims) -> retval:
    """
    @brief Renders on 3 channels input

    Output image must be 8-bit unsigned planar 3-channel image

    @param src input image: 8-bit unsigned 3-channel image @ref CV_8UC3
    @param prims draw primitives
    """

def renderNV12(y, uv, prims) -> retval:
    """
    @brief Renders on two planes

    Output y image must be 8-bit unsigned planar 1-channel image @ref CV_8UC1
    uv image must be 8-bit unsigned planar 2-channel image @ref CV_8UC2

    @param y  input image: 8-bit unsigned 1-channel image @ref CV_8UC1
    @param uv input image: 8-bit unsigned 2-channel image @ref CV_8UC2
    @param prims draw primitives
    """
